<?php 

/*

# core / aural.php
#
# This file contains information about the aural data structure
# Composed by three classes
# 1 - AuralDataStructureDA - creates the aural structure for a DA
# 2 - AuralDataStructureTA - creates the aural structure for a TA
# 3 - AuralDataStructureIA - creates the aural structure for a IA

# @author: Alberto Terragni - Stefano Vaghi
# @version: 0.3

*/

include( $_SERVER['DOCUMENT_ROOT'].substr($_SERVER['PHP_SELF'], 0, strpos($_SERVER['PHP_SELF'], "/", 1)).'/configuration.php' );

//require_once( $site_absolute_path.'core/db.php' );
require_once( $site_absolute_path.'core/session.php' );
require_once( $site_absolute_path.'core/idm.php' );




/******************************************************************************************/
/******************************************************************************************/
/***********************************         DA         ***********************************/
/******************************************************************************************/
/******************************************************************************************/


/*
	Class that builds the aural access data struture for a dialogue act
*/
class AuralDataStructureDA {

	private $auralDataStructure = "";  //Variable containing the structure of the accessible page to pass to smarty

	private $da;  //Contains the dialogue act
		
	private $smarty;  //Reference to smarty object
	
	private $language;  //Current language of the website
	
	private $sessionObj;  //variable containing the session
	
	/*
		Constructor of the class
	*/
	public function __construct($da, $smarty, $language, $sessionObj) 
	{	
		$this->da = $da;
		$this->smarty = $smarty;
		$this->language = $language;
		$this->sessionObj = $sessionObj;
		
		//include the file for the aural language
		$auralLanguageFile = $this->sessionObj->getAuralLanguageFile($this->language);
		require_once( 'languages/aural/'.$auralLanguageFile );
	}

	/*
		Create the data structure of a dialogue act
	*/
	public function createAuralPage()
	{
		$counterSection = 0;  //counter to keep track of the section's number
		
		//SECTION [0]: Schema
		$schemaSection = $this->createSchemaSection();
		$counterSection = $counterSection + 1;
		
		$this->auralDataStructure .= $schemaSection;
		
		//Ricorda che topic pu essere inattivo e anche i singoli dialogue act (magari inglese s, italiano no).
		//SECTION [1]: Main content
		$mainContent = $this->createMainContent($counterSection);
		$counterSection = $counterSection + 1;
		$this->auralDataStructure .= $mainContent;
		
		//SECTION [2]: Structural links
		if( $this->thereAreStructuralLinks() )
		{
			$structuralLinks = $this->createStructuralLinks($counterSection);
			$counterSection = $counterSection + 1;
			$this->auralDataStructure .= $structuralLinks;
		}
		
		//SECTION [3]: Transition links
		if( $this->thereAreTransitionLinks() )
		{
			$transitionLinks = $this->createTransitionLinks($counterSection);
			$counterSection = $counterSection + 1;
			$this->auralDataStructure .= $transitionLinks;
		}
		
		//SECTION [4]: Orientation information
		/***********  UNDER CONTRUCTION: by now is just the orientation without backward *********/
		if( true )
		{
			$orientation = $this->createOrientationSection($counterSection);
			$counterSection = $counterSection + 1;
			$this->auralDataStructure .= $orientation;
		}
		
		//SECTION [5]: Navigation area
		if( $this->thereAreElementsInMenu() )
		{
			$navigationArea = $this->createNavigationArea($counterSection);
			$this->auralDataStructure .= $navigationArea;
		}
		
		return $this->auralDataStructure;
	}
	
	/*
		Create the schema section of the page
	*/	
	public function createSchemaSection()
	{
		$schemaSection = "";  //variable that contains the schema section
		
		$dialogueActTitle = $this->da->getTitleDA();  //get the title of the dialogue act
		
		$topicTitle = $this->da->getLabelDA();  //get the title of the topic
		
		$generalTopicName = "";  //general name of the topic (e.g: "theatre, "print"...)
		
		$counterSection = 1;  //Counter to kkep track of the number of sections
		
		$isMultipleTopic = false;  //check if it is a multiple or single topic
		
		$numberOfSections = $this->calculateNumberSections();
		
		$m_topic_id = $this->da->getMTopicId();
		$s_topic_id = $this->da->get_topic_id();
		
		if( $m_topic_id != NULL )
		{
			$isMultipleTopic = true;
		}
		
		//if it's a multiple topic, obtain the general name
		/*if($isMultipleTopic)
		{		
			$query =  "SELECT DISTINCT idm_name ";
			$query .= "FROM _TABLEPREFIX_s_topic, _TABLEPREFIX_c_topic ";
			$query .= "WHERE _TABLEPREFIX_s_topic.id = _TABLEPREFIX_c_topic.s_topic_id
AND _TABLEPREFIX_c_topic.s_topic_id = ".$s_topic_id."";
			
			$result = DBManager::exeQuery($query);
			$row = mysql_fetch_array($result);
			$generalTopicName = $row['idm_name'];
		}*/
		
		$schemaSection = "
			<div>
				<h1>"._CONTENT_." '".$dialogueActTitle."', "._OF_THE_TOPIC_." '".$topicTitle."'.</h1>
				
				<p>"._PAGE_IN_." ".$numberOfSections." "._SECTIONS_.". "._SELECT_DESIRED_.". "._SECTIONS_ARE_.".</p>
				
				<ul>
					<li><a href='#main'>"._SECTION_." ".$counterSection.". "._MAIN_CONTENT_OF_.". '".$dialogueActTitle."'.</a></li>";
					
			$counterSection = $counterSection + 1;
			
			//check if there are strctural links
			if( $this->thereAreStructuralLinks() )
			{
				$schemaSection .= "	
					<li><a href='#structural'>"._SECTION_." ".$counterSection.". "._ADDITIONAL_ABOUT_." '".$topicTitle."'.</a></li>";
			
				$counterSection = $counterSection + 1;
			}
			
			//check if there are transition links	
			if( $this->thereAreTransitionLinks() )
			{
				$schemaSection .= "	
					<li><a href='#relative'>"._SECTION_." ".$counterSection.". "._INFORMATION_RELATED_." '".$topicTitle."'.</a></li>";
					
				$counterSection = $counterSection + 1;
			}
			
			/***********  UNDER CONTRUCTION: by now is just a default link ****************/
			//check if there are orientation information
			if(true)
			{
				$schemaSection .= "	
					<li><a href='#orientation'>"._SECTION_." ".$counterSection.". "._ORIENTATION_INFORMATION_.".</a></li>";
						
				$counterSection = $counterSection + 1;
			}
			
			//check if there's at least one element in one menu
			if( $this->thereAreElementsInMenu() )
			{
				$schemaSection .= "	
					<li><a href='#navigation'>"._SECTION_." ".$counterSection.". "._NAVIGATION_AREA_.".</a></li>";
			}
			
			$schemaSection .= "	
				</ul>
			</div>";
			
		return $schemaSection;
	}
	
	/*
		Create the main content section	  
	*/
	public function createMainContent($numberOfSection)
	{
		$mainContentSection = "";  //variable that contains the structural links section
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$dialogueActTitle = $this->da->getTitleDA();  //get the title of the dialogue act
		
		$mainContentSection .= "
			<div>
				<h1 id='main'>"._SECTION_." ".$sectionNumber.". "._MAIN_CONTENT_OF_.". '".$dialogueActTitle."'.</h1>
				";
		
		// render output text (Content of DA)
		$content = $this->da->renderItems($this->smarty);
		
		// render output text (Global items of Topic)
		$st = $this->da->getST($this->language, $this->smarty);
		$globalItem = $st->renderGlobalItems($this->smarty);
		
		$totItems = count($content) + count($globalItem);  //total number of items (DA items + globals)
		
		$_output = "";
		
		if($totItems !=0)
		{
			// TEXT
			//generate content structure for DA text items
			foreach ($content as $thing => $contentType)
			{
				switch($thing) 
				{
					case "htmlText":
						foreach ($contentType as $content)
						{
							if (!strcmp($content['behaviour'],"error"))
							{
								$_output_temp = "<p>"._ERROR_TEXT_."</p>";	
							}
							elseif (!strcmp($content['behaviour'],"default"))
							{
								$_output_temp ="";
								if(strcmp($content['content'],""))
									$_output_temp = $content['content'];
							}
							else
							{
								$_output_temp = "";
							}
							$_output .= $_output_temp;
						}	
					break;
					
					default:
					break;
				}
			}
			
			//generate content structure for global text items
			foreach ($globalItem as $thing => $contentType)
			{
				switch($thing) 
				{
					case "htmlText":
						foreach ($contentType as $content)
						{
							if (!strcmp($content['behaviour'],"error"))
							{
								$_output_temp = "<p>"._ERROR_TEXT_."</p>";	
							}
							elseif (!strcmp($content['behaviour'],"default"))
							{
								$_output_temp ="";
								if(strcmp($content['content'],""))
									$_output_temp = $content['content'];
							}
							else
							{
								$_output_temp = "";
							}
							$_output .= $_output_temp;
						}	
					break;
					
					default:
					break;
				}
			}
			
			$mainContentSection .= $_output;
			
			$_output = "";

			// render output text (Content of DA)
			$content = $this->da->renderItems($this->smarty);	
			
			// render output text (Global items of Topic)
			$st = $this->da->getST($this->language, $this->smarty);
			$globalItem = $st->renderGlobalItems($this->smarty);
			
			//IMAGE
			//check the number of images: if >= 1, create the subsection
			$numberOfImages = $this->calculateNumberItems("image");
			
			if( $numberOfImages > 0 )
			{
				$mainContentSection .= "
					<h2>"._IMAGES_.".</h2>";
				
				if( $numberOfImages == 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_IS_." ".$numberOfImages." "._IMAGE_.".</p>";
				}
				
				if( $numberOfImages > 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_ARE_." ".$numberOfImages." "._IMAGES_.".</p>";
				}
				
				$mainContentSection .= "
					<ul>";
				
				$imageCounter = 1;
				
				//generate content structure for DA image items			
				foreach ($content as $thing => $contentType)
				{
					switch($thing) 
					{
						case "image":
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp = "
						<li>"._IMAGE_." ".$imageCounter." "._OF_." ".$numberOfImages.". "._ERROR_IMG_."</li>";
									$imageCounter = $imageCounter + 1;
								}
								elseif (!strcmp($content['behaviour'],"default"))	
								{	
									$_output_temp ="";
									if(strcmp($content['img_thumb'],""))
									{
										$_output_temp ='
						<li>'._IMAGE_.' '.$imageCounter.' '._OF_.' '.$numberOfImages.'. <img src="content/image/thumbnail/'.$content['img_thumb'].'" alt="'.$content['description'].'" /></li>';
									}
									$imageCounter = $imageCounter + 1;
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
							}
						break;
						
						default:
						break;
					}
				}
				
				//generate content structure for global image items			
				foreach ($globalItem as $thing => $contentType)
				{
					switch($thing) 
					{
						case "image":
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp = "
						<li>"._IMAGE_." ".$imageCounter." "._OF_." ".$numberOfImages.". "._ERROR_IMG_."</li>";
									$imageCounter = $imageCounter + 1;
								}
								elseif (!strcmp($content['behaviour'],"default"))	
								{	
									$_output_temp ="";
									if(strcmp($content['img_thumb'],""))
									{
										$_output_temp ='
						<li>'._IMAGE_.' '.$imageCounter.' '._OF_.' '.$numberOfImages.'. <img src="content/image/thumbnail/'.$content['img_thumb'].'" alt="'.$content['description'].'" /></li>';
									}
									$imageCounter = $imageCounter + 1;
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
							}
						break;
						
						default:
						break;
					}
				}
				
				$_output .= "
					</ul>";
			}

			$mainContentSection .= $_output;
			
			$_output = "";

			// render output text (Content of DA)
			$content = $this->da->renderItems($this->smarty);	
			
			// render output text (Global items of Topic)
			$st = $this->da->getST($this->language, $this->smarty);
			$globalItem = $st->renderGlobalItems($this->smarty);
			
			//AUDIO
			//check the number of audio: if >= 1, create the subsection
			$numberOfAudio = $this->calculateNumberItems("audio");
			
			if( $numberOfAudio > 0 )
			{
				$mainContentSection .= "
					<h2>"._AUDIO_.".</h2>";
				
				if( $numberOfAudio == 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_IS_." ".$numberOfAudio." "._AUDIO_S_.".</p>";
				}
				
				if( $numberOfAudio > 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_ARE_." ".$numberOfAudio." "._AUDIO_.".</p>";
				}
				
				$mainContentSection .= "
					<ul>";
				
				$audioCounter = 1;
				
				//generate content structure for DA audio items			
				foreach ($content as $thing => $contentType)
				{
					switch($thing) 
					{		
						case "audio":
							$audio_player_height =20;
							$audio_player_width =320;
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp ='
						<li>'._AUDIO_S_.' '.$audioCounter.' '._OF_.' '.$numberOfAudio.'. '._ERROR_AUDIO_.'.</li>';
									$audioCounter = $audioCounter + 1;
								}
								
								elseif (!strcmp($content['behaviour'],"default"))	
								{	
									//check if there's a transcription
									$thereIsTranscription = false;
									
									$transcriptionFile = substr_replace($content['file'], 'txt', -3, 3);  //eventual file for transcription is <videonam>.txt
									
									foreach(scandir("content/audio") as $file_dir)
									{
										if( !strcmp($file_dir,$transcriptionFile) )
										{
											$thereIsTranscription = true;
										}
									}
									
									$_output_temp ="";
									if(strcmp($content['file'],""))
									{
										$_output_temp ='
						<li>'._AUDIO_S_.' '.$audioCounter.' '._OF_.' '.$numberOfAudio.'. '.$content["title"].'. ';
										$_output_temp .= _AUTHOR_.' "'.$content["author"].'". ';
										$_output_temp .= _DESCRIPTION_.': '.$content["description"].'. ';
										
										$player="player_audio".$content['id'];
										$_output_temp .='<span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to use this player.</span> ';
								
										$_output_temp .='<script type="text/javascript">';
										$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "single", "'.$audio_player_width.'", "'.$audio_player_height.'", "7");';
										$_output_temp .='s3.addVariable("file","content/audio/'.$content['file'].'");';
										$_output_temp .='s3.addVariable("repeat","true");';
										$_output_temp .='s3.addVariable("showdigits","true");';
										$_output_temp .='s3.write("'.$player.'");';
										$_output_temp .='</script>';
										
										if( $thereIsTranscription )
										{
											$_output_temp .=' <a href="content/audio/'.$transcriptionFile.'">'._TRANSC_AUDIO_.'.</a></li>';
										}
									}
									
									$audioCounter = $audioCounter + 1;	
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
								
							}
						break;
						
						default:
						break;
					}
				}
				
				//generate content structure for global audio items			
				foreach ($globalItem as $thing => $contentType)
				{
					switch($thing) 
					{		
						case "audio":
							$audio_player_height =20;
							$audio_player_width =320;
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp ='
						<li>'._AUDIO_S_.' '.$audioCounter.' '._OF_.' '.$numberOfAudio.'. '._ERROR_AUDIO_.'.</li>';
									$audioCounter = $audioCounter + 1;
								}
								
								elseif (!strcmp($content['behaviour'],"default"))	
								{	
									//check if there's a transcription
									$thereIsTranscription = false;
									
									$transcriptionFile = substr_replace($content['file'], 'txt', -3, 3);  //eventual file for transcription is <videonam>.txt
									
									foreach(scandir("content/audio") as $file_dir)
									{
										if( !strcmp($file_dir,$transcriptionFile) )
										{
											$thereIsTranscription = true;
										}
									}
									
									$_output_temp ="";
									if(strcmp($content['file'],""))
									{
										$_output_temp ='
						<li>'._AUDIO_S_.' '.$audioCounter.' '._OF_.' '.$numberOfAudio.'. '.$content["title"].'. ';
										$_output_temp .= _AUTHOR_.' "'.$content["author"].'". ';
										$_output_temp .= _DESCRIPTION_.': '.$content["description"].'. ';
										
										$player="player_audio".$content['id'];
										$_output_temp .='<span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to use this player.</span> ';
								
										$_output_temp .='<script type="text/javascript">';
										$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "single", "'.$audio_player_width.'", "'.$audio_player_height.'", "7");';
										$_output_temp .='s3.addVariable("file","content/audio/'.$content['file'].'");';
										$_output_temp .='s3.addVariable("repeat","true");';
										$_output_temp .='s3.addVariable("showdigits","true");';
										$_output_temp .='s3.write("'.$player.'");';
										$_output_temp .='</script>';
										
										if( $thereIsTranscription )
										{
											$_output_temp .=' <a href="content/audio/'.$transcriptionFile.'">'._TRANSC_AUDIO_.'.</a></li>';
										}
									}
									
									$audioCounter = $audioCounter + 1;	
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
								
							}
						break;
						
						default:
						break;
					}
				}
				
				$_output .= "
					</ul>";
			}
			
			$mainContentSection .= $_output;
			
			$_output = "";
			
			// render output text (Content of DA)
			$content = $this->da->renderItems($this->smarty);	
			
			// render output text (Global items of Topic)
			$st = $this->da->getST($this->language, $this->smarty);
			$globalItem = $st->renderGlobalItems($this->smarty);
			
			//VIDEO
			//check the number of video: if >= 1, create the subsection
			$numberOfVideo = $this->calculateNumberItems("video");
			
			if( $numberOfVideo > 0 )
			{
				$mainContentSection .= "
					<h2>"._VIDEO_.".</h2>";
				
				if( $numberOfVideo == 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_IS_." ".$numberOfVideo." "._VIDEO_S_.".</p>";
				}
				
				if( $numberOfVideo > 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_ARE_." ".$numberOfVideo." "._VIDEO_.".</p>";
				}
				
				$mainContentSection .= "
					<ul>";
				
				$videoCounter = 1;
				
				//generate content structure for DA video items			
				foreach ($content as $thing => $contentType)
				{
					switch($thing) 
					{		
						case "video":
							$video_player_height =240;
							$video_player_width =320;
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp ='
						<li>'._VIDEO_S_.' '.$videoCounter.' '._OF_.' '.$numberOfVideo.'. '._ERROR_VIDEO_.'.</li>';
									$videoCounter = $videoCounter + 1;
								}
								
								elseif (!strcmp($content['behaviour'],"default"))	
								{	
									//check if there's a transcription
									$thereIsTranscription = false;
									
									$transcriptionFile = substr_replace($content['file'], 'txt', -3, 3);  //eventual file for transcription is <videoname>.txt
									
									foreach(scandir("content/video") as $file_dir)
									{
										if( !strcmp($file_dir,$transcriptionFile) )
										{
											$thereIsTranscription = true;
										}
									}
									
									$_output_temp ="";
									if(strcmp($content['file'],""))
									{
										$_output_temp ='
						<li>'._VIDEO_S_.' '.$videoCounter.' '._OF_.' '.$numberOfVideo.'. '.$content["title"].'. ';
										$_output_temp .= _AUTHOR_.' "'.$content["author"].'". ';
										$_output_temp .= _DESCRIPTION_.': '.$content["description"].'. ';
										
										$player="player_video".$content['id'];
										$_output_temp .='<span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to see this player.</span>';
										$_output_temp .='<script type="text/javascript">';
										$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "playlist", "'.$video_player_width.'", "'.$video_player_height.'", "7");';
										$_output_temp .='s3.addVariable("file","../content/video/'.$content['file'].'");';
										$_output_temp .='s3.addVariable("repeat","true");';
										$_output_temp .='s3.addVariable("showdigits","true");';
										$_output_temp .='s3.write("'.$player.'");';
										$_output_temp .='</script>';
										
										if( $thereIsTranscription )
										{
											$_output_temp .=' <a href="content/video/'.$transcriptionFile.'">'._TRANSC_VIDEO_.'.</a></li>';
										}
									}
									
									$videoCounter = $videoCounter + 1;	
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
								
							}
						break;
						
						default:
						break;
					}
				}
				
				//generate content structure for global video items			
				foreach ($globalItem as $thing => $contentType)
				{
					switch($thing) 
					{		
						case "video":
							$video_player_height =240;
							$video_player_width =320;
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp ='
						<li>'._VIDEO_S_.' '.$videoCounter.' '._OF_.' '.$numberOfVideo.'. '._ERROR_VIDEO_.'.</li>';
									$videoCounter = $videoCounter + 1;
								}
								
								elseif (!strcmp($content['behaviour'],"default"))	
								{	
									//check if there's a transcription
									$thereIsTranscription = false;
									
									$transcriptionFile = substr_replace($content['file'], 'txt', -3, 3);  //eventual file for transcription is <videonam>.txt
									
									foreach(scandir("content/video") as $file_dir)
									{
										if( !strcmp($file_dir,$transcriptionFile) )
										{
											$thereIsTranscription = true;
										}
									}
									
									$_output_temp ="";
									if(strcmp($content['file'],""))
									{
										$_output_temp ='
						<li>'._VIDEO_S_.' '.$videoCounter.' '._OF_.' '.$numberOfVideo.'. '.$content["title"].'. ';
										$_output_temp .= _AUTHOR_.' "'.$content["author"].'". ';
										$_output_temp .= _DESCRIPTION_.': '.$content["description"].'. ';
										
										$player="player_video".$content['id'];
										$_output_temp .='<span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to see this player.</span>';
										$_output_temp .='<script type="text/javascript">';
										$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "playlist", "'.$video_player_width.'", "'.$video_player_height.'", "7");';
										$_output_temp .='s3.addVariable("file","../content/video/'.$content['file'].'");';
										$_output_temp .='s3.addVariable("repeat","true");';
										$_output_temp .='s3.addVariable("showdigits","true");';
										$_output_temp .='s3.write("'.$player.'");';
										$_output_temp .='</script>';
										
										if( $thereIsTranscription )
										{
											$_output_temp .=' <a href="content/video/'.$transcriptionFile.'">'._TRANSC_VIDEO_.'.</a></li>';
										}
									}
									
									$videoCounter = $videoCounter + 1;	
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
								
							}
						break;
						
						default:
						break;
					}
				}
				
				$_output .= "
					</ul>";
			}
			
			$mainContentSection .= $_output;
			
			$_output = "";
			
			// render output text (Content of DA)
			$content = $this->da->renderItems($this->smarty);
			
			// render output text (Global items of Topic)
			$st = $this->da->getST($this->language, $this->smarty);
			$globalItem = $st->renderGlobalItems($this->smarty);
			
			//URL
			//check the number of url: if >= 1, create the subsection
			$numberOfUrl = $this->calculateNumberItems("url");
			
			if( $numberOfUrl > 0 )
			{
				$mainContentSection .= "
					<h2>"._RESOURCES_.".</h2>";
				
				if( $numberOfUrl == 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_IS_." ".$numberOfUrl." "._RESOURCES_S_.".</p>";
				}
				
				if( $numberOfUrl > 1 )
				{
					$mainContentSection .= "
					<p>"._THERE_ARE_." ".$numberOfUrl." "._RESOURCES_.".</p>";
				}
				
				$mainContentSection .= "
					<ul>";
				
				$urlCounter = 1;
				
				//generate content structure for DA url items			
				foreach ($content as $thing => $contentType)
				{
					switch($thing) 
					{		
						case "url":
							
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp ='
						<li>'._RESOURCES_S_.' '.$urlCounter.' '._OF_.' '.$numberOfUrl.'. '._ERROR_URL_.'.</li>';
									$urlCounter = $urlCounter + 1;
								}
								elseif (!strcmp($content['behaviour'],"default"))
								{	
									$_output_temp ="";
									if(strcmp($content['url'],""))
									{
										$_output_temp ='
						<li>'._RESOURCES_S_.' '.$urlCounter.' '._OF_.' '.$numberOfUrl.'. <a href="'.$content['url'].'">'.$content['label'].'</a></li>';
									}
										
									$urlCounter = $urlCounter + 1;
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
							}	
						break;
						
						default:
						break;
					}
				}
				
				//generate content structure for global url items			
				foreach ($globalItem as $thing => $contentType)
				{
					switch($thing) 
					{		
						case "url":
							
							foreach ($contentType as $content)
							{
								if (!strcmp($content['behaviour'],"error"))
								{
									$_output_temp ='
						<li>'._RESOURCES_S_.' '.$urlCounter.' '._OF_.' '.$numberOfUrl.'. '._ERROR_URL_.'.</li>';
									$urlCounter = $urlCounter + 1;
								}
								elseif (!strcmp($content['behaviour'],"default"))
								{	
									$_output_temp ="";
									if(strcmp($content['url'],""))
									{
										$_output_temp ='
						<li>'._RESOURCES_S_.' '.$urlCounter.' '._OF_.' '.$numberOfUrl.'. <a href="'.$content['url'].'">'.$content['label'].'</a></li>';
									}
										
									$urlCounter = $urlCounter + 1;
								}
								else
								{
									$_output_temp = "";
								}
								$_output .= $_output_temp;
							}	
						break;
						
						default:
						break;
					}
				}
				
				$_output .= "
					</ul>";
			}
			
			$mainContentSection .= $_output;
		}
		
		$mainContentSection .= "
			</div>";	
		
		return $mainContentSection;
	}
	
	/*
		Create the structural link section	  
	*/
	public function createStructuralLinks($numberOfSection)
	{
		$structuralLinkSection = "";  //variable that contains the structural links section
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$topicTitle = $this->da->getLabelDA();  //get the title of the topic
		
		$structuralLinks = $this->da->getStructuralLinks();  //structural links of the topic
		
		$totStructuralLinks = count($structuralLinks);  //total number of structural links
		
		//var_dump($structuralLinks);
		
		$structuralLinkSection = "
			<div>
				<h1 id='structural'>"._SECTION_." ".$sectionNumber.". "._ADDITIONAL_ABOUT_." '".$topicTitle."'.</h1>
				
				<ul>";
		
		$strcuturalLinkCounter = 1;  //keep track of the number of the current link
		
		$_output = "";  //output of the list of links
		
		//cycle over the structural links
		foreach( $structuralLinks as $structuralLink )
		{
			if ($structuralLink['current'])
		 	{
				$_output .='
					<li><a href="'.$structuralLink['url'].'"';
				$_output .='title="'.$structuralLink['label'].'">';
				$_output .=$strcuturalLinkCounter.' '._OF_.' '.$totStructuralLinks.'. ';
				$_output .=$structuralLink['label'].' ('._CURRENT_.').</a></li>';
				
				$strcuturalLinkCounter = $strcuturalLinkCounter + 1; 
			}
			else
			{
				$_output .='
					<li><a href="'.$structuralLink['url'].'"';
				$_output .='title="'.$structuralLink['label'].'">';
				$_output .=$strcuturalLinkCounter.' '._OF_.' '.$totStructuralLinks.'. ';
				$_output .=$structuralLink['label'].'.</a></li>';
				
				$strcuturalLinkCounter = $strcuturalLinkCounter + 1; 
			}
		}
		
		$structuralLinkSection .= $_output;
		
		$structuralLinkSection .= "
				</ul>
			</div>";
			
		return $structuralLinkSection;
		
	}
	
	/*
		Create the transition link section	  
	*/
	public function createTransitionLinks($numberOfSection)
	{
		$transitionLinkSection = "";  //variable that contains the transition links section
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$topicTitle = $this->da->getLabelDA();  //get the title of the topic
		
		$transition_links = $this->da->getTransitionLinks();
		$transition_act_info = $this->da->getTransitionActInfo();
		$ta_name = "";
		
		$_output = '';
		$_output1 = '';
		
		$transitionLinkSection .= "
			<div>
				<h1 id='relative'>"._SECTION_." ".$sectionNumber.". "._INFORMATION_RELATED_." '".$topicTitle."'.</h1>
				";
				
		$numberOfTransitions = $this->numberOfTypeTransition($transition_act_info, $transition_links, $ta_name);  //calculate the different types of possible transitions
		
		if( $numberOfTransitions == 1 )
		{
			$transitionLinkSection .=	"
					<p>"._THERE_IS_." ".$numberOfTransitions." "._TYPE_OF_INFO_." '".$topicTitle."'.</p>";
		}
		
		if( $numberOfTransitions > 1 )
		{
			$transitionLinkSection .=	"
					<p>"._THERE_ARE_." ".$numberOfTransitions." "._TYPES_OF_INFO_." '".$topicTitle."'.</p>";
		}
		
		if (count ($transition_links) !=0)
		{
			//QUESTO IF  PROVVISORIO: CODICE VALIDO DA ELSE
			if (!empty($ta_name))
			{
				if(array_key_exists($ta_name,$transition_act_info))
				{
					if(count ($transition_act_info[$ta_name]) !=0)
					{	
						foreach ($transition_act_info as $thing => $transition_act)
						{
							if (!strcmp($thing,$ta_name))
							{
								if ($transition_act['mode'] =="direct_transition")
								{
									$_output1 .= $transition_act['relation_title'];
									if ($transition_act['introductory_text']!="")
										$_output1 .= $transition_act['introductory_text'];
								}
								else 
								{
									$_output1 .='<a class="'.$link_style.'" href="'.$transition_act['url'].'"';
									$_output1 .='title="'.$transition_act['relation_title'].'">';
									$_output1 .=$transition_act['relation_title'].'</a>';
									$_output .= $_output1;
									return $_output;
								}
							}
						}
						foreach ($transition_links[$ta_name] as $tl_link)
						{
							if ($tl_link['label']!="")
							{
								$_output1 .='<a class="'.$link_style.'" href="'.$tl_link['url'].'"';
								$_output1 .='title="'.$tl_link['label'].'">';
								$_output1 .=$tl_link['label'].'</a>';
							}
							else
							{
								$_output1 .='<span class="'.$introduction.'">no name</span>';
							}
						}
					}
				}
				else
				{
					$_output1 .='<div id="'.$transitionLinks_box.'">';
					$_output1 .='The transition act is not available';
					$_output1 .='</div>';
				}
			}
			else
			{			
				$counterTransition = 1;
				
				foreach ($transition_act_info as $thing => $transition_act)
				{
					if (count ( $transition_act) !=0 )
					{
						if ($transition_act['mode'] =="direct_transition")
						{
							$_output1 .= "
					<h2>"._INFORMATION_." ".$counterTransition." "._OF_." ".$numberOfTransitions.". ".$transition_act['relation_title']."</h2>
					";
							if ($transition_act['introductory_text']!="")
							{
								$_output1 .= "
						<p>".$transition_act['introductory_text']."</p>";
							}
							$counterTransition = $counterTransition + 1;
						}
						else 
						{
							$_output1 .='
					<h2>'._INFORMATION_.' '.$counterTransition.' '._OF_.' '.$numberOfTransitions.'. <a href="'.$transition_act['url'].'&mt_id='.$transition_act['from_topic_id'].'"';
							$_output1 .='title="'.$transition_act['relation_title'].'">';
							$_output1 .=$transition_act['relation_title'].'</a></h2>
					';
							$counterTransition = $counterTransition + 1;
							continue 1;
						}
						
						$_output1 .='
						<ul>';
						
						$linkCounter = 1;
						
						$totLink = count($transition_links[$thing]);
						
						foreach ($transition_links[$thing] as $tl_link)
						{
							if ($tl_link['label']!="")
							{
								$_output1 .='
							<li><a href="'.$tl_link['url'].'"';
								$_output1 .='title="'.$tl_link['label'].'">';
								$_output1 .=$linkCounter.' '._OF_.' '.$totLink.'. '.$tl_link['label'].'</a></li>';
							}
							else
							{
								$_output1 .='<span>no name</span>';
							}
							$linkCounter = $linkCounter + 1;
						}
						$_output1 .='
						</ul>
						';
					}	
				}
			}
		}
		$_output .= $_output1;
		
		$transitionLinkSection .= $_output; 
		
		$transitionLinkSection .= "
			</div>";
					
		return $transitionLinkSection;
	}
	
	/*
		Create the orientation section
	*/
	/***  UNDER CONTRUCTION: by now is just the orientation without backward ***/
	public function createOrientationSection($numberOfSection)
	{
		$orientationSection = "";  //variable that contains the orientation section
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$dialogueActTitle = $this->da->getTitleDA();  //get the title of the dialogue act
		
		$topicTitle = $this->da->getLabelDA();  //get the title of the topic
		
		$orientationSection .= "
			<div>
				<h1 id='orientation'>"._SECTION_." ".$sectionNumber.". "._ORIENTATION_INFORMATION_.".</h1>
					<p>"._BROWSING_CONTENT_." '".$dialogueActTitle."' "._OF_THE_TOPIC_." '".$topicTitle."'.</p>";
					
		$orientationSection .= "
			</div>";
				
		return $orientationSection;
	}
	
	/*
		Create the navigation section
	*/
	public function createNavigationArea($numberOfSection)
	{
		$navigationArea = "";  //variable that contains the navigation area
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$menu_names=Navigator::getMenuNames($this->language);
		$menu_nav=array();
		
		$subSectionNumber = $this->calculateNumberSubSections();  //calculate the number of subsections in the navigation area
		
		$siteLanguages = $this->smarty->getSiteLanguages();  //obtain the active languages of the website
		
		$navigationArea .= "
			<div>
				<h1 id='navigation'>"._SECTION_." ".$sectionNumber.". "._NAVIGATION_AREA_.".</h1>
					<p>"._NAVIGATION_ORGANIZED_." ".$subSectionNumber." "._SUBSECTIONS_.". "._SELECT_DESIRED_SUB_.". "._SUBSECTIONS_ARE_.".</p>
		";
		
		
		$navigationArea .= $this->createNavigationAnchor();
		
		
		//BEGINNING OF THE NAVIGATION MENU
		$subSectionCounter = 1;
		
		//create an array containing all the information of all menu.
		//every element of the menu are accessible using the key of the menu (nav1, nav2....) 
		foreach ($menu_names as $menu_name)
		{
			$menu_nav[$menu_name]=Navigator::getMenu($menu_name, $this->language);
		}
		
		$numberOfMenu = $this->numberOfMenu($menu_names, $menu_nav);  //the number of menu
		
		$navigationArea .= "
					<h2 id='navigation_menu'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._NAVIGATION_MENU_.".</h2>";
	
		if( $numberOfMenu == 1 )
		{
			$navigationArea .=	"
						<p>"._THERE_IS_." ".$numberOfMenu." "._NAVIGATION_MENU_MIN_.".</p>";
		}
		
		if( $numberOfMenu > 1 )
		{
			$navigationArea .=	"
						<p>"._THERE_ARE_." ".$numberOfMenu." "._NAVIGATION_MENU_MIN_.".</p>";
		}
		
		$_output = "";
		
		$menuCounter = 1;
		
		$home = $this->smarty->get_template_vars('home');
		$home_id = $this->sessionObj->getHomePage_id();
		
		$st = $this->da->getST($this->language, $this->smarty);
		$s_topic_id = $st->get_topic_id();
		
		if( $home_id == $s_topic_id  )
		{
			$home = true;
		}
		
		foreach( $menu_names as $menu )	
		{
			if (count($menu_nav[$menu]) != 0 & !($home == true & count($menu_nav[$menu]) == 1))
			{
				
				$_output .="
							<h3>"._MENU_." ".$menuCounter." "._OF_." ".$numberOfMenu.".</h3>
							<ul>";
				
				$linkCounter = 1;
				
				$numberOfLinkInMenu = $this->calculateNumberLinkInMenu($menu_nav[$menu]);
				
				foreach ($menu_nav[$menu] as $menu_name)
				{
				
					//verifica che l'elemento da visualizzare non sia l'elemento corrente
					if ($menu_name['current']!=true)
					{
					
						if($home_id!=$menu_name['s_topic_id'])
						{
							$_output .='
								<li>';
							$_output .='<a href="'.$menu_name['url'].'"title="';
							$_output .=$menu_name['title'].'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							$linkCounter = $linkCounter + 1;
						}
						
						elseif($home!=true)
						{
							$_output .='
								<li>';
							$_output .='<a href="'.$menu_name['url'].'"title="';
							$_output .=$menu_name['title'].'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							$linkCounter = $linkCounter + 1;
						}
					}
					else
					{
						if($home!=true & $home_id!=$menu_name['s_topic_id'])
						{
							 $_output .='
								<li>';
							 $_output .='<a href="'.$menu_name['url'].'"title="'.$menu_name['title'].'">'; 
							 $_output .=$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
						     $_output .='</li>';
							
							$linkCounter = $linkCounter + 1;
						}
					}
					 
				}
				
				$_output .="
							</ul>
				";
				$menuCounter = $menuCounter + 1;
			}
			else
			{	
				continue;
			}
		}
		
		$navigationArea .= $_output;
		
		$subSectionCounter = $subSectionCounter + 1;
		
		//BEGINNING OF LANGUAGE SUBSECTION
		if( count($siteLanguages) > 1 )
		{
			$navigationArea .= "
					<h2 id='languages'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._LANGUAGES_.".</h2>";
			
			$navigationArea .=	"
						<p>"._THERE_ARE_." ".count($siteLanguages)." "._LANGUAGES_AVAILABLE_.".</p>
						";
			
			$languageCounter = 1;
			
			$_output = "
						<ul>";
			
			foreach ($siteLanguages as $site_language)
			{
				$_output .='
							<li><a href="'.$site_language['url'].'&'.$_SERVER['QUERY_STRING'].'"';
				$_output .='title="'.$site_language['title'].'">';
				$_output .=_LANGUAGE_.' '.$languageCounter.' '._OF_.' '.count($siteLanguages).'. '.$site_language['title'].'</a></li>';
				
				$languageCounter = $languageCounter + 1;
			}
			
			$_output .= "
						</ul>";
			
			$navigationArea .= $_output;
			
			$subSectionCounter = $subSectionCounter + 1;
		}
		
		//BEGINNING OF CREDIT SECTION. By now it's a static section
		if( true )
		{
			$navigationArea .= "
					<h2 id='credits'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._CREDITS_.".</h2>";
					
			$navigationArea .= "
					<ul>
						<li><a href='http://idmos.svn.sourceforge.net'>1 "._OF_." 1. "._IDMOS_POWER_.".</a></li>
						<li><a href='http://validator.w3.org/check?uri=referer'>1 "._OF_." 2. "._XHTML_VALID_.".</a></li>
						<li><a href='http://jigsaw.w3.org/css-validator'>1 "._OF_." 3. "._CSS_VALID_.".</a></li>
					</ul>";
		}
		
		$navigationArea .= "
			</div>";
		
		return $navigationArea;
	}
	
	/*
		Calculate the number of sections of the page 
	*/
	public function calculateNumberSections()
	{
		$numberSection = 1;
		
		if( $this->thereAreStructuralLinks() )
		{
			$numberSection = $numberSection + 1;
		}
		
		if( $this->thereAreTransitionLinks() )
		{
			$numberSection = $numberSection + 1;
		}
		
		/***********  UNDER CONTRUCTION: by now there's always orientation ****************/
		//check if there are orientation information
		if(true)
		{					
			$numberSection = $numberSection + 1;
		}

		if( $this->thereAreElementsInMenu() )
		{
			$numberSection = $numberSection + 1;
		}
		
		return $numberSection;
	}
	
	/*
		Calculate the number of possible transitions ff the DA 
	*/
	public function numberOfTypeTransition($transition_act_info, $transition_links, $ta_name)
	{
		$numberTransitions = 0;
		
		if (count ($transition_links) !=0)
		{
			//QUESTO IF  PROVVISORIO: CODICE VALIDO DA ELSE
			if (!empty($ta_name))
			{
				if(array_key_exists($ta_name,$transition_act_info))
				{
					if(count ($transition_act_info[$ta_name]) !=0)
					{	
						foreach ($transition_act_info as $thing => $transition_act)
						{
							$numberTransitions = $numberTransitions + 1;
						}
					}
				}
			}
			else
			{						
				foreach ($transition_act_info as $thing => $transition_act)
				{
					if (count ( $transition_act) !=0 )
					{
						$numberTransitions = $numberTransitions + 1;
					}	
				}
			}
		}
		
		return $numberTransitions;
	}
	
	/*
		Check if there are structural links in the DA
	*/
	public function thereAreStructuralLinks()
	{
		if( count($this->da->getStructuralLinks()) > 1 )
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/*
		Check if there are transition links in the DA
	*/
	public function thereAreTransitionLinks()
	{
		$transitionLinks = $this->da->getTransitionLinks();
		
		//check if there are transition links
		if( count($transitionLinks) > 0 )
		{
			$isThereOneTransition = false;  //variable to check if there's at leat one transition link
			
			foreach( $transitionLinks as $transitionTitle )
			{				
				
				foreach( $transitionTitle as $key => $value2 )
				{
					$isThereOneTransition = true;
				}
			
			}
			
			if( $isThereOneTransition )
			{
				return true;
			}
			else
			{
				return false;
			}
		}
		
		return false;
	}
	
	/*
		Check if there's at least one element in one menu 
	*/
	public function thereAreElementsInMenu()
	{
		$query =  "SELECT count(*) ";
		$query .= "FROM _TABLEPREFIX_c_menu2element ";
		$query .= "WHERE status = 'active' ";
		
		$result = DBManager::exeQuery($query);
		$row = mysql_fetch_array($result);
		$numberElementsMenu = $row['count(*)'];
		
		if($numberElementsMenu > 0)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/*
		Calculate the number of menu
	*/
	public function numberOfMenu($menu_names, $menu_nav)
	{
		$numberOfMenu = 0;
		
		$home = $this->smarty->get_template_vars('home');
		$home_id = $this->sessionObj->getHomePage_id();
		
		$st = $this->da->getST($this->language, $this->smarty);
		$s_topic_id = $st->get_topic_id();
		
		if( $home_id == $s_topic_id )
		{
			$home = true;
		}
		
		foreach( $menu_names as $menu )	
		{
			
			if (count($menu_nav[$menu]) != 0  & !($home == true & count($menu_nav[$menu]) == 1))
			{
				$numberOfMenu = $numberOfMenu + 1;
			}
			else
			{	
				continue;
			}
			
		}

		return $numberOfMenu;
	}
	
	/*
		Calculate the number of subsections for the navigation area 
	*/
	public function calculateNumberSubSections()
	{
		$numberSection = 1;
		
		$siteLanguages = $this->smarty->getSiteLanguages();
		
		//check if there's more than one language
		if( count($siteLanguages) > 1 )
		{
			$numberSection = $numberSection + 1;
		}
		
		//UNDER CONSTRUCTION: credits are set as default in the website
		if( true )
		{
			$numberSection = $numberSection + 1;
		}
		
		return $numberSection;
	}
	
	/*
		Calculate the number of link in menu 
	*/
	public function calculateNumberLinkInMenu($menu_nav)
	{
		$numberLink = count($menu_nav);
		
		$home = $this->smarty->get_template_vars('home');

		$home_id = $this->sessionObj->getHomePage_id();
		
		$st = $this->da->getST($this->language, $this->smarty);
		$s_topic_id = $st->get_topic_id();
		
		if( $home == true )
		{
			foreach ($menu_nav as $menu_name)
			{
				if( $home_id == $menu_name['s_topic_id'] )
				{
					$numberLink = $numberLink - 1;
				}
			}
		}
		
		elseif( $home_id == $s_topic_id  )
		{
			foreach ($menu_nav as $menu_name)
			{
				if( $home_id == $menu_name['s_topic_id'] )
				{
					$numberLink = $numberLink - 1;
				}
			}
		}

		return $numberLink;
	}
	
	/*
		Calculate the number of subsections for the navigation area 
	*/
	public function createNavigationAnchor()
	{
		$anchor = "";
		
		$numberSubsections = $this->calculateNumberSubSections();
		
		$counterSection = 1;
		
		$siteLanguages = $this->smarty->getSiteLanguages();
		
		$anchor .= "
					<ul>
						<li><a href='#navigation_menu'>"._SUBSECTION_." ".$counterSection.". "._NAVIGATION_MENU_.".</a></li>";
						
		$counterSection = $counterSection + 1;
		
		if( count($siteLanguages) > 1 )
		{
			$anchor .= "
						<li><a href='#languages'>"._SUBSECTION_." ".$counterSection.". "._LANGUAGES_.".</a></li>";
						
			$counterSection = $counterSection + 1;
		}
	
		//UNDER CONSTRUCTION: credits are set as default in the website
		if( true )
		{
			$anchor .= "
						<li><a href='#credits'>"._SUBSECTION_." ".$counterSection.". "._CREDITS_.".</a></li>";
		}
		
		$anchor .= "
					</ul>";
		
		return $anchor;
	}
	
	/*
		Calculate the number of items of type "itemType". Number =  error + default
	*/
	public function calculateNumberItems($itemType)
	{
		$numberItems = 0;
		
		// render output text (Content of DA)
		$content = $this->da->renderItems($this->smarty);	
		
		// render output text (Global items of Topic)
		$st = $this->da->getST($this->language, $this->smarty);
		$globalItem = $st->renderGlobalItems($this->smarty);
	
		//calculate DA image elements		
		foreach ($content as $thing => $contentType)
		{
			switch($thing) 
			{
				case $itemType:
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
						{
							$numberItems = $numberItems + 1;
						}
						elseif (!strcmp($content['behaviour'],"default"))	
						{	
							$numberItems = $numberItems + 1;
						}
						else
						{
						}
					}
				break;
				
				default:
				break;
			}
		}
		
		//calculate Topic image elements	
		foreach ($globalItem as $thing => $contentType)
		{
			switch($thing) 
			{
				case $itemType:
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
						{
							$numberItems = $numberItems + 1;
						}
						elseif (!strcmp($content['behaviour'],"default"))	
						{	
							$numberItems = $numberItems + 1;
						}
						else
						{
						}
					}
				break;
				
				default:
				break;
			}
		}
		
		return $numberItems;
	}

}



/******************************************************************************************/
/******************************************************************************************/
/***********************************         TA         ***********************************/
/******************************************************************************************/
/******************************************************************************************/




/*
	Class that builds the aural access data struture for a transition act
*/
class AuralDataStructureTA {

	private $auralDataStructure = "";  //Variable containing the structure of the accessible page to pass to smarty

	private $ta;  //Contains the transition act
		
	private $smarty;  //Reference to smarty object
	
	private $language;  //Current language of the website
	
	private $sessionObj;  //variable containing the session
	
	private $fromTopicMT_ID;  //the mt_id of the topic the user came from
	
	/*
		Constructor of the class
	*/
	public function __construct($ta, $smarty, $language, $sessionObj) 
	{	
		$this->ta = $ta;
		$this->smarty = $smarty;
		$this->language = $language;
		$this->sessionObj = $sessionObj;
		$this->fromTopicMT_ID = $_REQUEST['mt_id'];
		
		//include the file for the aural language
		$auralLanguageFile = $this->sessionObj->getAuralLanguageFile($this->language);
		require_once( 'languages/aural/'.$auralLanguageFile );
	}

	/*
		Create the data structure of a transition act
	*/
	public function createAuralPage()
	{
		$counterSection = 0;  //counter to keep track of the section's number
		
		
		//SECTION [0]: Schema
		$schemaSection = $this->createSchemaSection();
		$counterSection = $counterSection + 1;
		$this->auralDataStructure .= $schemaSection;
		
		
		//SECTION [1]: TA links
		if( $this->thereAreTALinks() )
		{
			$taLinks = $this->createTALinks($counterSection);
			$counterSection = $counterSection + 1;
			$this->auralDataStructure .= $taLinks;
		}
		
		//SECTION [2]: Navigation area
		if( $this->thereAreElementsInMenu() )
		{
			$navigationArea = $this->createNavigationArea($counterSection);
			$this->auralDataStructure .= $navigationArea;
		}
		
		return $this->auralDataStructure;
	}
	
	/*
		Create the schema section of the page
	*/	
	public function createSchemaSection()
	{
		$schemaSection = "";  //variable that contains the schema section
		
		$taTitle = $this->ta->getName();  //get the title of the transition act
		
		$taTitleTopic = $this->getTitleTopic($this->fromTopicMT_ID);  //get the title of the topic user came from
		
		$counterSection = 1;  //Counter to kkep track of the number of sections
		
		$numberOfSections = $this->calculateNumberSections();
	
		$schemaSection = "
			<div>
				<h1>"._CONTENT_." '".$taTitle."' "._OF_THE_TOPIC_." '".$taTitleTopic."'.</h1>
				<p>"._PAGE_IN_." ".$numberOfSections." "._SECTIONS_.". "._SELECT_DESIRED_.". "._SECTIONS_ARE_.".</p>
				<ul>
						";
						
			//check if there are  links in the transition act
			if( $this->thereAreTALinks() )
			{
				$schemaSection .= "	
					<li><a href='#transition'>"._SECTION_." ".$counterSection.". "._CONTENT_." '".$taTitle."' "._OF_THE_TOPIC_." ".$taTitleTopic.".</a></li>";
				$counterSection = $counterSection + 1;
			}
					
			//check if there's at least one element in one menu
			if( $this->thereAreElementsInMenu() )
			{
				$schemaSection .= "	
					<li><a href='#navigation'>"._SECTION_." ".$counterSection.". "._NAVIGATION_AREA_.".</a></li>";
			}
			
			$schemaSection .= "	
				</ul>
			</div>";
			
		return $schemaSection;
	}
	
	/*
		Create the TA link section	  
	*/
	public function createTALinks($numberOfSection)
	{
		$taSection = "";  //variable that contains the links
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$taTitle = $this->ta->getName();  //get the title of the TA
		
		$taLinks = $this->ta->getTransitionLinks();  // links of the TA
		
		$totTALinks = count($taLinks);  //total number of links
		
		$taIntro = $this->ta->getIntroductoryText();  //get the intro of the TA
		
		$taTitleTopic = $this->getTitleTopic($this->fromTopicMT_ID);  //get the title of the topic user came from
		
		$taSection = "
			<div>
				<h1 id='transition'>"._SECTION_." ".$sectionNumber.". "._CONTENT_." '".$taTitle."' "._OF_THE_TOPIC_." '".$taTitleTopic."'.</h1>";
		
		$taLinkCounter = 1;  //keep track of the number of the current link
		
		$_output = "";  //output of the list of links
		
		$_output .= "
				".$taIntro;
		
		if( $totTALinks == 1 )
		{
			$_output .= "
				<p>"._THERE_IS_." ".$totTALinks." "._ELEMENT_ORDER_.".</p>";  //output of the introduction to the list, with the semantic order
		}
		if( $totTALinks > 1 )
		{
			$_output .= "
				<p>"._THERE_ARE_." ".$totTALinks." "._ELEMENTS_ORDER_.". "._ORDER_IS_.": 'alphbetical'.</p>";  //output of the introduction to the list, with the semantic order
		}
				
		$_output .= "
				<ul>"; 
		
		//cycle over the links
		foreach( $taLinks as $taLink )
		{
				$_output .='
					<li><a href="'.$taLink['url'].'"';
				$_output .=' title="'.$taLink['label'].'">';
				$_output .=$taLinkCounter.' '._OF_.' '.$totTALinks.'. ';
				$_output .=$taLink['label'].'.</a></li>';
				
				$taLinkCounter = $taLinkCounter + 1; 
		}
		
		$taSection .= $_output;
		
		$taSection .= "
				</ul>
			</div>";
			
		return $taSection;
		
	}
	
	/*
		Create the navigation section
	*/
	public function createNavigationArea($numberOfSection)
	{
		$navigationArea = "";  //variable that contains the navigation area
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$menu_names=Navigator::getMenuNames($this->language);
		$menu_nav=array();
		
		$subSectionNumber = $this->calculateNumberSubSections();  //calculate the number of subsections in the navigation area
		
		$siteLanguages = $this->smarty->getSiteLanguages();  //obtain the active languages of the website
		
		$navigationArea .= "
			<div>
				<h1 id='navigation'>"._SECTION_." ".$sectionNumber.". "._NAVIGATION_AREA_.".</h1>
					<p>"._NAVIGATION_ORGANIZED_." ".$subSectionNumber." "._SUBSECTIONS_.". "._SELECT_DESIRED_SUB_.". "._SUBSECTIONS_ARE_.".</p>
		";
		
		
		$navigationArea .= $this->createNavigationAnchor();
		
		
		//BEGINNING OF THE NAVIGATION MENU
		$subSectionCounter = 1;
		
		//create an array containing all the information of all menu.
		//every element of the menu are accessible using the key of the menu (nav1, nav2....) 
		foreach ($menu_names as $menu_name)
		{
			$menu_nav[$menu_name]=Navigator::getMenu($menu_name, $this->language);
		}
		
		$numberOfMenu = $this->numberOfMenu($menu_names, $menu_nav);  //the number of menu
		
		$navigationArea .= "
					<h2 id='navigation_menu'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._NAVIGATION_MENU_.".</h2>";
	
		if( $numberOfMenu == 1 )
		{
			$navigationArea .=	"
						<p>"._THERE_IS_." ".$numberOfMenu." "._NAVIGATION_MENU_MIN_.".</p>";
		}
		
		if( $numberOfMenu > 1 )
		{
			$navigationArea .=	"
						<p>"._THERE_ARE_." ".$numberOfMenu." "._NAVIGATION_MENU_MIN_.".</p>";
		}
		
		$_output = "";
		
		$menuCounter = 1;

		$home = $this->smarty->get_template_vars('home');
		$home_id = $this->sessionObj->getHomePage_id();
		
		foreach( $menu_names as $menu )	
		{
			if (count($menu_nav[$menu]) != 0 & !($home == true & count($menu_nav[$menu]) == 1))
			{
				
				$_output .="
							<h3>"._MENU_." ".$menuCounter." "._OF_." ".$numberOfMenu.".</h3>
							<ul>";
				
				$linkCounter = 1;
				
				$numberOfLinkInMenu = $this->calculateNumberLinkInMenu($menu_nav[$menu]);
				
				foreach ($menu_nav[$menu] as $menu_name)
				{
				
					//verifica che l'elemento da visualizzare non sia l'elemento corrente
					if ($menu_name['current']!=true)
					{
					
						if($home_id!=$menu_name['s_topic_id'])
						{
							$_output .='
								<li>';
							$_output .='<a href="'.$menu_name['url'].'"title="';
							$_output .=$menu_name['title'].'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							$linkCounter = $linkCounter + 1;
						}
						
						elseif($home!=true)
						{
							$_output .='
								<li>';
							$_output .='<a href="'.$menu_name['url'].'"title="';
							$_output .=$menu_name['title'].'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							$linkCounter = $linkCounter + 1;
						}
					}
					else
					{
					
						if($home!=true & $home_id!=$menu_nav['id'])
						{
							 $_output .='
								 <li>';
							 $_output .='<a href="'.$menu_name['url'].'"title="'.$menu_name['title'].'"'; 
							$_output .='class="'.$current_element_style.'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							
							$linkCounter = $linkCounter + 1;
						}
					}
					 
				}
				
				$_output .="
							</ul>
				";
				$menuCounter = $menuCounter + 1;
			}
			else
			{	
				continue;
			}
		}
		
		$navigationArea .= $_output;
		
		$subSectionCounter = $subSectionCounter + 1;
		
		//BEGINNING OF LANGUAGE SUBSECTION
		if( count($siteLanguages) > 1 )
		{
			$navigationArea .= "
					<h2 id='languages'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._LANGUAGES_.".</h2>";
			
			$navigationArea .=	"
						<p>"._THERE_ARE_." ".count($siteLanguages)." "._LANGUAGES_AVAILABLE_.".</p>
						";
			
			$languageCounter = 1;
			
			$_output = "
						<ul>";
			
			foreach ($siteLanguages as $site_language)
			{
				$_output .='
							<li><a href="'.$site_language['url'].'&'.$_SERVER['QUERY_STRING'].'"';
				$_output .='title="'.$site_language['title'].'">';
				$_output .=_LANGUAGE_.' '.$languageCounter.' '._OF_.' '.count($siteLanguages).'. '.$site_language['title'].'</a></li>';
				
				$languageCounter = $languageCounter + 1;
			}
			
			$_output .= "
						</ul>";
			
			$navigationArea .= $_output;
			
			$subSectionCounter = $subSectionCounter + 1;
		}
		
		//BEGINNING OF CREDIT SECTION. By now it's a static section
		if( true )
		{
			$navigationArea .= "
					<h2 id='credits'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._CREDITS_.".</h2>";
					
			$navigationArea .= "
					<ul>
						<li><a href='http://idmos.svn.sourceforge.net'>1 "._OF_." 1. "._IDMOS_POWER_.".</a></li>
						<li><a href='http://validator.w3.org/check?uri=referer'>1 "._OF_." 2. "._XHTML_VALID_.".</a></li>
						<li><a href='http://jigsaw.w3.org/css-validator'>1 "._OF_." 3. "._CSS_VALID_.".</a></li>
					</ul>";
		}
		
		$navigationArea .= "
			</div>";
		
		return $navigationArea;
	}
	
	/*
		Calculate the number of sections of the page 
	*/
	public function calculateNumberSections()
	{
		$numberSection = 0;
		
		if( $this->thereAreTALinks() )
		{
			$numberSection = $numberSection + 1;
		}

		if( $this->thereAreElementsInMenu() )
		{
			$numberSection = $numberSection + 1;
		}
		
		return $numberSection;
	}
	
	/*
		Get the name of the topic user came from
	*/
	public function getTitleTopic($mt_id)
	{
		$query =  "SELECT label ";
		$query .= "FROM _TABLEPREFIX_c_topic ";
		$query .= "WHERE id = ".$mt_id." ";
		
		$result = DBManager::exeQuery($query);
		$row = mysql_fetch_array($result);
		$topicTitle = $row['label'];
		
		return $topicTitle;
	}
	
	/*
		Check if there are  links in the TA
	*/
	public function thereAreTALinks()
	{
		if( count($this->ta->getTransitionLinks()) > 0 )
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/*
		Check if there's at least one element in one menu 
	*/
	public function thereAreElementsInMenu()
	{
		$query =  "SELECT count(*) ";
		$query .= "FROM _TABLEPREFIX_c_menu2element ";
		$query .= "WHERE status = 'active' ";
		
		$result = DBManager::exeQuery($query);
		$row = mysql_fetch_array($result);
		$numberElementsMenu = $row['count(*)'];
		
		if($numberElementsMenu > 0)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/*
		Calculate the number of menu
	*/
	public function numberOfMenu($menu_names, $menu_nav)
	{
		$numberOfMenu = 0;

		$home = $this->smarty->get_template_vars('home');
		$home_id = $this->sessionObj->getHomePage_id();
		
		foreach( $menu_names as $menu )	
		{
			
			if (count($menu_nav[$menu]) != 0  & !($home == true & count($menu_nav[$menu]) == 1))
			{
				$numberOfMenu = $numberOfMenu + 1;
			}
			else
			{	
				continue;
			}
			
		}

		return $numberOfMenu;
	}
	
	/*
		Calculate the number of subsections for the navigation area 
	*/
	public function calculateNumberSubSections()
	{
		$numberSection = 1;
		
		$siteLanguages = $this->smarty->getSiteLanguages();
		
		//check if there's more than one language
		if( count($siteLanguages) > 1 )
		{
			$numberSection = $numberSection + 1;
		}
		
		//UNDER CONSTRUCTION: credits are set as default in the website
		if( true )
		{
			$numberSection = $numberSection + 1;
		}
		
		return $numberSection;
	}
	
	/*
		Calculate the number of subsections for the navigation area 
	*/
	public function createNavigationAnchor()
	{
		$anchor = "";
		
		$numberSubsections = $this->calculateNumberSubSections();
		
		$counterSection = 1;
		
		$siteLanguages = $this->smarty->getSiteLanguages();
		
		$anchor .= "
					<ul>
						<li><a href='#navigation_menu'>"._SUBSECTION_." ".$counterSection.". "._NAVIGATION_MENU_.".</a></li>";
						
		$counterSection = $counterSection + 1;
		
		if( count($siteLanguages) > 1 )
		{
			$anchor .= "
						<li><a href='#languages'>"._SUBSECTION_." ".$counterSection.". "._LANGUAGES_.".</a></li>";
						
			$counterSection = $counterSection + 1;
		}
	
		//UNDER CONSTRUCTION: credits are set as default in the website
		if( true )
		{
			$anchor .= "
						<li><a href='#credits'>"._SUBSECTION_." ".$counterSection.". "._CREDITS_.".</a></li>";
		}
		
		$anchor .= "
					</ul>";
		
		return $anchor;
	}
	
	/*
		Calculate the number of link in menu 
	*/
	public function calculateNumberLinkInMenu($menu_nav)
	{
		$numberLink = count($menu_nav);

		return $numberLink;
	}
}



/******************************************************************************************/
/******************************************************************************************/
/***********************************         IA         ***********************************/
/******************************************************************************************/
/******************************************************************************************/


/*
	Class that builds the aural access data struture for an introductory act
*/
class AuralDataStructureIA {

	private $auralDataStructure = "";  //Variable containing the structure of the accessible page to pass to smarty

	private $ia;  //Contains the introductory act
		
	private $smarty;  //Reference to smarty object
	
	private $language;  //Current language of the website
	
	private $sessionObj;  //variable containing the session
	
	/*
		Constructor of the class
	*/
	public function __construct($ia, $smarty, $language, $sessionObj) 
	{	
		$this->ia = $ia;
		$this->smarty = $smarty;
		$this->language = $language;
		$this->sessionObj = $sessionObj;
		
		//include the file for the aural language
		$auralLanguageFile = $this->sessionObj->getAuralLanguageFile($this->language);
		require_once( 'languages/aural/'.$auralLanguageFile );
	}

	/*
		Create the data structure of an introductory act
	*/
	public function createAuralPage()
	{
		$counterSection = 0;  //counter to keep track of the section's number
		
		//SECTION [0]: Schema
		$schemaSection = $this->createSchemaSection();
		$counterSection = $counterSection + 1;
		$this->auralDataStructure .= $schemaSection;
		
		
		//SECTION [1]: IA links 
		if( $this->thereAreIALinks() )
		{
			$iaLinks = $this->createIALinks($counterSection);
			$counterSection = $counterSection + 1;
			$this->auralDataStructure .= $iaLinks;
		}
		
		//SECTION [2]: Navigation area
		if( $this->thereAreElementsInMenu() )
		{
			$navigationArea = $this->createNavigationArea($counterSection);
			$this->auralDataStructure .= $navigationArea;
		}
		
		return $this->auralDataStructure;
	}

	/*
		Create the schema section of the page
	*/	
	public function createSchemaSection()
	{
		$schemaSection = "";  //variable that contains the schema section
		
		$iaTitle = $this->ia->getName();  //get the title of the introductory act
		
		$counterSection = 1;  //Counter to keep track of the number of sections
		
		$numberOfSections = $this->calculateNumberSections();
	
		$schemaSection = "
			<div>
				<h1>"._CONTENT_OF_." '".$iaTitle."'.</h1>
				<p>"._PAGE_IN_." ".$numberOfSections." "._SECTIONS_.". "._SELECT_DESIRED_.". "._SECTIONS_ARE_.".</p>
				<ul>
						";
					
						
			//check if there are  links nel introductory act
			if( $this->thereAreIALinks() )
			{
				$schemaSection .= "	
					<li><a href='#structural'>"._SECTION_." ".$counterSection.". "._CONTENT_OF_." '".$iaTitle."'.</a></li>";
				$counterSection = $counterSection + 1;
			}
			
			
					
			//check if there's at least one element in one menu
			if( $this->thereAreElementsInMenu() )
			{
				$schemaSection .= "	
					<li><a href='#navigation'>"._SECTION_." ".$counterSection.". "._NAVIGATION_AREA_.".</a></li>";
			}
			
			$schemaSection .= "	
				</ul>
			</div>";
			
		return $schemaSection;
	}
	
	
	/*
		Create the IA link section	  
	*/
	public function createIALinks($numberOfSection)
	{
		$iaSection = "";  //variable that contains the links
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$iaTitle = $this->ia->getName();  //get the title of the IA
		
		$iaLinks = $this->ia->getIntroductoryLinks();  // links of the IA
		
		$totIALinks = count($iaLinks);  //total number of links
		
		$iaIntro = $this->ia->getIntroductoryText();  //get the intro of the IA
		
		
		$iaSection = "
			<div>
				<h1 id='structural'>"._SECTION_." ".$sectionNumber.". "._CONTENT_OF_." '".$iaTitle."'.</h1>
				<ul>
					";
		
		$iaLinkCounter = 1;  //keep track of the number of the current link		
			
		$_output = "";  //output of the list of links
		
		$_output .= "
				".$iaIntro;
		
		if( $totIALinks == 1 )
		{
			$_output .= "
				<p>"._THERE_IS_." ".$totIALinks." "._ELEMENT_ORDER_.".</p>";  //output of the introduction to the list, with the semantic order
		}
		if( $totIALinks > 1 )
		{
			$_output .= "
				<p>"._THERE_ARE_." ".$totIALinks." "._ELEMENTS_ORDER_.". "._ORDER_IS_.": 'alphbetical'.</p>";  //output of the introduction to the list, with the semantic order
		}
				
		$_output .= "
				<ul>"; 
		
		
		
		
		//cycle over the links
		foreach( $iaLinks as $iaLink )
		{	
				$_output .='<li><a href="'.$iaLink['url'].'"';
				$_output .='title="'.$iaLink['label'].'">';
				$_output .=$iaLinkCounter.' '._OF_.' '.$totIALinks.'. ';
				$_output .=$iaLink['label'].'.</a></li>';
				
				$iaLinkCounter = $iaLinkCounter + 1; 
			
		}
		
		$iaSection .= $_output;
		
		$iaSection .= "
				</ul>
			</div>";
			
		return $iaSection;
		
	}
	
	/*
		Create the navigation section
	*/
	public function createNavigationArea($numberOfSection)
	{
		$navigationArea = "";  //variable that contains the navigation area
		
		$sectionNumber = $numberOfSection;  //number of the section
		
		$menu_names=Navigator::getMenuNames($this->language);
		$menu_nav=array();
		
		$subSectionNumber = $this->calculateNumberSubSections();  //calculate the number of subsections in the navigation area
		
		$siteLanguages = $this->smarty->getSiteLanguages();  //obtain the active languages of the website
		
		$navigationArea .= "
			<div>
				<h1 id='navigation'>"._SECTION_." ".$sectionNumber.". "._NAVIGATION_AREA_.".</h1>
					<p>"._NAVIGATION_ORGANIZED_." ".$subSectionNumber." "._SUBSECTIONS_.". "._SELECT_DESIRED_SUB_.". "._SUBSECTIONS_ARE_.".</p>
		";
		
		
		$navigationArea .= $this->createNavigationAnchor();
		
		
		//BEGINNING OF THE NAVIGATION MENU
		$subSectionCounter = 1;
		
		//create an array containing all the information of all menu.
		//every element of the menu are accessible using the key of the menu (nav1, nav2....) 
		foreach ($menu_names as $menu_name)
		{
			$menu_nav[$menu_name]=Navigator::getMenu($menu_name, $this->language);
		}
		
		$numberOfMenu = $this->numberOfMenu($menu_names, $menu_nav);  //the number of menu
		
		$navigationArea .= "
					<h2 id='navigation_menu'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._NAVIGATION_MENU_.".</h2>";
	
		if( $numberOfMenu == 1 )
		{
			$navigationArea .=	"
						<p>"._THERE_IS_." ".$numberOfMenu." "._NAVIGATION_MENU_MIN_.".</p>";
		}
		
		if( $numberOfMenu > 1 )
		{
			$navigationArea .=	"
						<p>"._THERE_ARE_." ".$numberOfMenu." "._NAVIGATION_MENU_MIN_.".</p>";
		}
		
		$_output = "";
		
		$menuCounter = 1;

		$home = $this->smarty->get_template_vars('home');
		$home_id = $this->sessionObj->getHomePage_id();
		
		foreach( $menu_names as $menu )	
		{
			if (count($menu_nav[$menu]) != 0 & !($home == true & count($menu_nav[$menu]) == 1))
			{
				
				$_output .="
							<h3>"._MENU_." ".$menuCounter." "._OF_." ".$numberOfMenu.".</h3>
							<ul>";
				
				$linkCounter = 1;
				
				$numberOfLinkInMenu = $this->calculateNumberLinkInMenu($menu_nav[$menu]);
				
				foreach ($menu_nav[$menu] as $menu_name)
				{
				
					//verifica che l'elemento da visualizzare non sia l'elemento corrente
					if ($menu_name['current']!=true)
					{
					
						if($home_id!=$menu_name['s_topic_id'])
						{
							$_output .='
								<li>';
							$_output .='<a href="'.$menu_name['url'].'"title="';
							$_output .=$menu_name['title'].'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							$linkCounter = $linkCounter + 1;
						}
						
						elseif($home!=true)
						{
							$_output .='
								<li>';
							$_output .='<a href="'.$menu_name['url'].'"title="';
							$_output .=$menu_name['title'].'">'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							$_output .='</li>';
							$linkCounter = $linkCounter + 1;
						}
					}
					else
					{
					
						if($home!=true & $home_id!=$menu_name['s_topic_id'])
						{
							 $_output .='
								<li>';
							 $_output .='<a href="'.$menu_name['url'].'"title="'.$menu_name['title'].'"'; 
							 $_output .='>'.$linkCounter.' '._OF_.' '.$numberOfLinkInMenu.'. '.$menu_name['label'].'</a>';
							 $_output .='</li>';
							
							$linkCounter = $linkCounter + 1;
						}
					}
					 
				}
				
				$_output .="
							</ul>
				";
				$menuCounter = $menuCounter + 1;
			}
			else
			{	
				continue;
			}
		}
		
		$navigationArea .= $_output;
		
		$subSectionCounter = $subSectionCounter + 1;
		
		//BEGINNING OF LANGUAGE SUBSECTION
		if( count($siteLanguages) > 1 )
		{
			$navigationArea .= "
					<h2 id='languages'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._LANGUAGES_.".</h2>";
			
			$navigationArea .=	"
						<p>"._THERE_ARE_." ".count($siteLanguages)." "._LANGUAGES_AVAILABLE_.".</p>
						";
			
			$languageCounter = 1;
			
			$_output = "
						<ul>";
			
			foreach ($siteLanguages as $site_language)
			{
				$_output .='
							<li><a href="'.$site_language['url'].'&'.$_SERVER['QUERY_STRING'].'"';
				$_output .='title="'.$site_language['title'].'">';
				$_output .=_LANGUAGE_.' '.$languageCounter.' '._OF_.' '.count($siteLanguages).'. '.$site_language['title'].'</a></li>';
				
				$languageCounter = $languageCounter + 1;
			}
			
			$_output .= "
						</ul>";
			
			$navigationArea .= $_output;
			
			$subSectionCounter = $subSectionCounter + 1;
		}
		
		//BEGINNING OF CREDIT SECTION. By now it's a static section
		if( true )
		{
			$navigationArea .= "
					<h2 id='credits'>"._SUBSECTION_." ".$subSectionCounter." "._OF_." ".$subSectionNumber.". "._CREDITS_.".</h2>";
					
			$navigationArea .= "
					<ul>
						<li><a href='http://idmos.svn.sourceforge.net'>1 "._OF_." 1. "._IDMOS_POWER_.".</a></li>
						<li><a href='http://validator.w3.org/check?uri=referer'>1 "._OF_." 2. "._XHTML_VALID_.".</a></li>
						<li><a href='http://jigsaw.w3.org/css-validator'>1 "._OF_." 3. "._CSS_VALID_.".</a></li>
					</ul>";
		}
		
		$navigationArea .= "
			</div>";
		
		return $navigationArea;
	}
	
	/*
		Calculate the number of sections of the page 
	*/
	public function calculateNumberSections()
	{
		$numberSection = 0;
		
		if( $this->thereAreIALinks() )
		{
			$numberSection = $numberSection + 1;
		}
			
		if( $this->thereAreElementsInMenu() )
		{
			$numberSection = $numberSection + 1;
		}

		return $numberSection;
	}
	
	/*
		Check if there are  links in the IA
	*/
	public function thereAreIALinks()
	{
		if( count($this->ia->getIntroductoryLinks()) > 0 )
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/*
		Check if there's at least one element in one menu 
	*/
	public function thereAreElementsInMenu()
	{
		$query =  "SELECT count(*) ";
		$query .= "FROM _TABLEPREFIX_c_menu2element ";
		$query .= "WHERE status = 'active' ";
		
		$result = DBManager::exeQuery($query);
		$row = mysql_fetch_array($result);
		$numberElementsMenu = $row['count(*)'];
		
		if($numberElementsMenu > 0)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/*
		Calculate the number of menu
	*/
	public function numberOfMenu($menu_names, $menu_nav)
	{
		$numberOfMenu = 0;

		$home = $this->smarty->get_template_vars('home');
		$home_id = $this->sessionObj->getHomePage_id();
		
		foreach( $menu_names as $menu )	
		{
			
			if (count($menu_nav[$menu]) != 0  & !($home == true & count($menu_nav[$menu]) == 1))
			{
				$numberOfMenu = $numberOfMenu + 1;
			}
			else
			{	
				continue;
			}
			
		}

		return $numberOfMenu;
	}
	
	/*
		Calculate the number of subsections for the navigation area 
	*/
	public function calculateNumberSubSections()
	{
		$numberSection = 1;
		
		$siteLanguages = $this->smarty->getSiteLanguages();
		
		//check if there's more than one language
		if( count($siteLanguages) > 1 )
		{
			$numberSection = $numberSection + 1;
		}
		
		//UNDER CONSTRUCTION: credits are set as default in the website
		if( true )
		{
			$numberSection = $numberSection + 1;
		}
		
		return $numberSection;
	}
	
	/*
		Calculate the number of subsections for the navigation area 
	*/
	public function createNavigationAnchor()
	{
		$anchor = "";
		
		$numberSubsections = $this->calculateNumberSubSections();
		
		$counterSection = 1;
		
		$siteLanguages = $this->smarty->getSiteLanguages();
		
		$anchor .= "
					<ul>
						<li><a href='#navigation_menu'>"._SUBSECTION_." ".$counterSection.". "._NAVIGATION_MENU_.".</a></li>";
						
		$counterSection = $counterSection + 1;
		
		if( count($siteLanguages) > 1 )
		{
			$anchor .= "
						<li><a href='#languages'>"._SUBSECTION_." ".$counterSection.". "._LANGUAGES_.".</a></li>";
						
			$counterSection = $counterSection + 1;
		}
	
		//UNDER CONSTRUCTION: credits are set as default in the website
		if( true )
		{
			$anchor .= "
						<li><a href='#credits'>"._SUBSECTION_." ".$counterSection.". "._CREDITS_.".</a></li>";
		}
		
		$anchor .= "
					</ul>";
		
		return $anchor;
	}
	
	/*
		Calculate the number of link in menu 
	*/
	public function calculateNumberLinkInMenu($menu_nav)
	{
		$numberLink = count($menu_nav);

		return $numberLink;
	}
}

?>