<?php



class XmlParser {

	private $xml = 'not initialized';

	public function __construct() {
		
		//Check the path of the file that request the method for includig configuration.php
		$requestPath = $_SERVER["SCRIPT_FILENAME"];
		if ( (strpos($requestPath, 'installation') === FALSE) and (strpos($requestPath, 'administrator') === FALSE))
			include( 'configuration.php' );
		else
			include( '../configuration.php' );
	
		//loads php into string
		if (file_exists($site_absolute_path.'core/idm_schema/'.$idm_file_name)) {
			$this->xml = simplexml_load_file($site_absolute_path.'core/idm_schema/'.$idm_file_name);
			//if you want to show xml content transformed into objects...
			//var_dump($this->xml);
		} else {
			exit('Failed to open source file.');
		}
	}
	
	public function isAlive(){
		if ($this->xml == 'not initialized') {
			return false;
		} else {
			return true;
		}
	}
	
	
	//Get single topic elements
	public function getSingleTopics(){
		$singleTopics = array();
		
		foreach($this->xml->singleTopic as $el) {
			$temp_array = array(
								'id' => (string) $el['id'],
								'label' => (string) $el['label'],
								);
			array_push($singleTopics, $temp_array);
		}
		
		return $singleTopics;
	}
	
	//Get multiple topic elements
	public function getMultipleTopics(){
		$multipleTopics = array();
		
		foreach($this->xml->multipleTopic as $el) {
			$temp_array = array(
								'id' => (string) $el['id'],
								'label' => (string) $el['label'],
								'navigationPattern' => (string) $el['navigationPattern'],
								);
			array_push($multipleTopics, $temp_array);
		}
		
		return $multipleTopics;
	}
	
	//Get dialogue act elements
	public function getDialogueActs(){
		$dialogueActs = array();
		$singleTopics = $this->xml->singleTopic;
		
		foreach($singleTopics as $singleTopic) {
			foreach($singleTopic->dialogueAct as $el){
				$temp_array = array(
									'id' => (string) $el['id'],
									'label' => (string) $el['label'],
									'isDefault' => (string) $el['isDefault'],
									'topic_id' => (string) $singleTopic['id']
									);
				array_push($dialogueActs, $temp_array);
			}
		}
		
		$multipleTopics = $this->xml->multipleTopic;
		
		foreach($multipleTopics as $multipleTopic) {
			foreach($multipleTopic->dialogueAct as $el){
				$temp_array = array(
									'id' => (string) $el['id'],
									'label' => (string) $el['label'],
									'isDefault' => (string) $el['isDefault'],
									'topic_id' => (string) $multipleTopic['id']
									);
				array_push($dialogueActs, $temp_array);
			}
		}
		
		return $dialogueActs;
	}
	
	//Get items elements
	public function getItems(){
		$items = array();
		$dialogueActs = $this->xml->xpath('//dialogueAct');
		
		foreach($dialogueActs as $dialogueAct) {
			foreach($dialogueAct->item as $el){
				$temp_array = array(
									'id' => (string) $el['id'],
									'type' => (string) $el['type'],
									'dialogue_act_id' => (string) $dialogueAct['id'],
									'topic_id' => '',
									'multiple' => ''
									);
				array_push($items, $temp_array);
			}
		}
		
		$singleTopics = $this->xml->singleTopic;
		
		foreach($singleTopics as $singleTopic) {
			if(is_array($singleTopic))
				foreach($singleTopic->globalItems->item as $el){
					$temp_array = array(
										'id' => (string) $el['id'],
										'type' => (string) $el['type'],
										'dialogue_act_id' => '',
										'topic_id' => (string) $singleTopic['id'],
										'multiple' => (string) $el['multiple']									
										);
					array_push($items, $temp_array);
				}
		}
		
		$multipleTopics = $this->xml->multipleTopic;
		
		foreach($multipleTopics as $multipleTopic) {
			if(is_array($multipleTopic))
				foreach($multipleTopic->globalItems->item as $el){
					$temp_array = array(
										'id' => (string) $el['id'],
										'type' => (string) $el['type'],
										'dialogue_act_id' => '',
										'topic_id' => (string) $multipleTopic['id'],
										'multiple' => (string) $el['multiple']									
										);
					array_push($items, $temp_array);
				}
		}
		
		return $items;
	}
	
	//Get Transition Act elements
	public function getTransitionActs(){
		$relations = array();
		
		foreach($this->xml->transitionAct as $rel){
			$temp_array = array(
								'id' => (string) $rel['id'],
								'label' => (string) $rel['label'],
								'fromMT' => (string) $rel['fromMT'],
								'toMT' => (string) $rel['toMT'],
								'fromCardinality' => (string) $rel['fromCardinality'],
								'toCardinality' => (string) $rel['toCardinality'],
								'hasIntroduction' => (string) $rel['hasIntroduction'],
								'mode' => (string) $rel['mode'],
								'navigationPattern' => (string) $rel['navigationPattern']
								);
		array_push($relations, $temp_array);
		}
		return $relations;
		
	}
	
	//Get Introductory Act elements
	public function getIntroductoryActs(){
		$introductoryActs = array();
		
		foreach($this->xml->introductoryAct as $el){
			$temp_array = array(
								'id' => (string) $el['id'],
								'label' => (string) $el['label'],
								'navigationPattern' => (string) $el['navigationPattern'],
								'hasIntroduction' => (string) $el['hasIntroduction']
								);
		array_push($introductoryActs, $temp_array);
		}
		return $introductoryActs;
		
	}
	
	//Get Introductory Act Reference elements (topics)
	public function getIntroductoryActsReferenceTopic(){
		$introductoryActsReference = array();
		$introductoryActs = $this->xml->introductoryAct;
		foreach($introductoryActs as $introductoryAct){
			//print_r($introductoryActs);
			foreach($introductoryAct->multipleTopicReference as $el)
			{
				$temp_array = array(
									'introductory_act_id' => (string) $introductoryAct['id'],				
									'topic_id' => (string) $el['id'],			
									'populationType' => (string) $el['populationType']
								);
				//print_r($temp_array);
				array_push($introductoryActsReference, $temp_array);
			}
		}
		return $introductoryActsReference;
		
	}
	
	//Get Introductory Act Reference elements (Introductory act)
	public function getIntroductoryActsReferenceIa(){
		$introductoryActsReference = array();
		$introductoryActs = $this->xml->introductoryAct;
		foreach($introductoryActs as $introductoryAct){
			//print_r($introductoryActs);
			foreach($introductoryAct->introductoryActReference as $el)
			{
				$temp_array = array(
									'introductory_act_id' => (string) $introductoryAct['id'],				
									'ia_id' => (string) $el['id'],			
									'populationType' => (string) $el['populationType']
								);
				//print_r($temp_array);
				array_push($introductoryActsReference, $temp_array);
			}
		}
		return $introductoryActsReference;
		
	}
	
	
	//dialogue act functions
	
	public function getDALabel($da_id){
		$label = "not found";
		
		foreach($this->xml->multipleTopic as $mt) {
			foreach($mt->dialogueAct as $da){
				if ((string)$da['id'] == $da_id) {
					$label = (string)$da['label'];
				}
			} 
		}
		
		foreach($this->xml->singleTopic as $st) {
			foreach($st->dialogueAct as $da){
				if ((string)$da['id'] == $da_id) {
					$label = (string)$da['label'];
				}
			} 
		}
		
		return $label;
	}
	
	public function getDAisDefault($da_id){
		foreach($this->xml->multipleTopic->dialogueAct as $da){
			if ((string)$da['id'] == $da_id) {
				return (string)$da['isDefault'];
			}
		}
	}
	
	public function getStructuralLinksOfMT($mt_id){
		$structuralLinks = array();
		
		foreach ($this->xml->multipleTopic as $mt) {
			if((string)$mt['id'] == $mt_id){
				foreach($mt->dialogueAct as $da){
					$da_id = $da['id'];
					$da_label = $da['label'];
					$da_isDefault = $da['isDefault'];
					array_push($structuralLinks, $da_id, $da_label, $da_isDefault);
				}
				//no need to continue, I've already done..
				continue;
			}
		}
		return $structuralLinks;
	}
	
	public function getStructuralLinksOfDA($da_id){
		$structuralLinks = array();
		
		foreach ($this->xml->multipleTopic as $mt) {
			foreach ($mt->dialogueAct as $da) {
				if ((string)$da['id'] == $da_id) {
					return $this->getStructuralLinksOfMT($mt['id']);
				}
			}
		}
	}	
	
	public function getMTName($mt_id){
		foreach($this->xml->multipleTopic as $mt){
			if ((string)$mt['id'] == $mt_id) {
				return (string)$mt['name'];
			}
		}
	}
	
	public function getMTStatus(){
		// to do
	}
	
	public function getMTDefaultDA($mt_id){
		foreach($this->xml->multipleTopic as $mt){
			if ((string)$mt['id'] == $mt_id) {
				foreach($mt->dialogueAct as $da) {
					
					//echo ("<br>DEBUG = ".(string)$da['isDefault']);
					
					if ((string)$da['isDefault'] == 'true') {
						return $da['id'];
					}
				}
			}
		}
	}
	
	public function getSTName($st_id){
		foreach($this->xml->singleTopic as $st){
			if ((string)$st['id'] == $st_id) {
				return (string)$st['name'];
			}
		}
	}
	
	public function getSTDefaultDA($st_id){
		foreach($this->xml->singleTopic as $st){
			if ((string)$st['id'] == $st_id) {
				foreach($st->dialogueAct as $da) {
					
					//echo ("<br>DEBUG = ".(string)$da['isDefault']);
					
					if ((string)$da['isDefault'] == 'true') {
						return $da['id'];
					}
				}
			}
		}
	}
	
	public function getIALabel($ia_id){
		foreach($this->xml->introductoryAct as $ia){
			if ((string)$ia['id'] == $ia_id) {
				return (string)$ia['label'];
			}
		}
	}
	
	public function getIANavigationPattern($ia_id){
		foreach($this->xml->introductoryAct as $ia){
			if ((string)$ia['id'] == $ia_id) {
				return (string)$ia['navigationPattern'];
			}
		}
	}
	
	public function getIAHasIntroduction($ia_id){
		foreach($this->xml->introductoryAct as $ia){
			if ((string)$ia['id'] == $ia_id) {
				return (string)$ia['hasIntroduction'];
			}
		}
	}
	
	public function getIAMultipleTopicsID($ia_id){
		$temp_array = array();
		
		foreach($this->xml->introductoryAct as $ia) {
			if ((string)$ia['id'] == $ia_id) {
				foreach($ia->multipleTopicReference as $mtr) {
					array_push($temp_array, (string)$mtr['id']);
				}
			}
		}
		
		return $temp_array;
	}
	
	public function getIAPopulation($ia_id, $mt_id){
		
		foreach($this->xml->introductoryAct as $ia) {
			if ((string)$ia['id'] == $ia_id) {
				foreach($ia->multipleTopicReference as $mtr) {
					if ((string)$mtr['id'] == $mt_id) {
						return (string)$mtr['populationType'];
					}
				}
			}
		}
	}

} //end class

?>