<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */


/**
 * Smarty {load_ia_navigator} function plugin
 *
 * File:       function.load_ia_navigator.php<br>
 * Type:       function<br>
 * Name:       load_ia_navigator<br>
 * Date:       30.Aug.2007<br>
 * Purpose:    Prints out the information that allow the navigation between the introductory act <br>

 * Input:<br>
 *   - menu_name       				(required) - string that indicates the menu   
 *   - link_style                   (optional) - string that indicates the style class of the  'a' tag element
 *   - link_active_style			(optional) - string that indicates the style class of the  active link element (this style is used for the all_to_all pattern)
 *   - navigator_box 				(optional) - string that indicates the style applyed to the 'div' tag element

********************************************************
******* parameter used for the guided tour *************

*    - image_previous				(optional) - string that indicates the path of the image used show the previous element of the list
*    - image_next					(optional) - string that indicates the path of the image used show the next element of the list


 * Examples:
 * {load_ia_navigator}
 

 * @author     Gabriele Perego - Stefano Sormani
 * @version    1.0
 */

require_once ( 'core/session.php' );
function smarty_function_load_ia_navigator($params, &$smarty)
{
	$sessionObj = new sessionManager();
    $ia_navigation_pattern=	$sessionObj->getVariable('ia_navigation_pattern');
	$active_ia=	$sessionObj->getVariable('active_ia');
	$ia_vector_mt=	$sessionObj->getVariable('ia_vector_mt');
	$current_element_style= $params['current_element_style'];
	$current_mt = $smarty->get_template_vars('current_mt');
	$orientation_label=	$sessionObj->getVariable('orientation_label');
	$navigator_box =  $params['navigator_box'];
	$link_style = $params['link_style'];
	$link_active_style = $params['link_active_style'];
	$back_label = $params['back_label'];
	$image_previous = $params['image_previous'];
	$image_next = $params['image_next'];
	$_output ='';
	
	if(isset($active_ia))
	{
		if($ia_navigation_pattern=="index")
		{
		$_output .='<div id="'.$navigator_box.'">';
		$_output .='<a class="'.$link_style.'" href="?ia='.$active_ia.'">'.$orientation_label.'</a>';
		$_output .='</div>';
		
		}
		
		if ($ia_navigation_pattern=="guided_tour")
		{
			$count=0;
			foreach ($ia_vector_mt as $mt)
			{
				if ($mt['id']==$current_mt)
				{
					$current_element=$count;
				}
			$count++;
			}
			$element= count($ia_vector_mt);
			if ($current_element==0)
			{
			$previous_element= $element-1;
			$previous_mt= $ia_vector_mt[$previous_element]['url'];
			$next_mt=$ia_vector_mt[1]['url'];
			$previous_label= $ia_vector_mt[$previous_element]['label'];
			$next_label=$ia_vector_mt[1]['label'];
			}
			
			elseif ($current_element+1 == count($ia_vector_mt))
			{
			$previous_element= $current_element-1;
			$previous_mt= $ia_vector_mt[$previous_element]['url'];
			$next_mt=$ia_vector_mt[0]['url'];
			$previous_label=$ia_vector_mt[$previous_element]['label'];
			$next_label=$ia_vector_mt[0]['label'];
			}
			else
			{
			$previous_element= $current_element-1;
			$next_element= $current_element+1;
			$previous_mt= $ia_vector_mt[$previous_element]['url'];
			$next_mt=$ia_vector_mt[$next_element]['url'];
			$previous_label=$ia_vector_mt[$previous_element]['label'];
			$next_label=$ia_vector_mt[$next_element]['label'];
			}
		$_output .='<div id="'.$navigator_box.'">';
		$_output .='<a href="'.$previous_mt.'"><img src="'.$image_previous.'" alt="'.$previous_label.'"/></a>';			
		$_output .=$previous_label;
		$_output .=' | ';
		$_output .=$next_label;
		
		$_output .='<a href="'.$next_mt.'"><img src="'.$image_next.'" alt="'.$next_label.'"/></a>';			
		$_output .='</div>';
		}
		
		if ($ia_navigation_pattern=="mixed_mode")
		{
		
		//navigator box for the index pattern
		$_output .='<div id="'.$navigator_box.'">';
		$_output .='<a class="'.$link_style.'" href="?ia='.$active_ia.'">'.$orientation_label.'</a>';
		$_output .='</div>';
		
		//navigator box for the guided tour pattern
		$count=0;
		foreach ($ia_vector_mt as $mt)
		{
			if ($mt['id']==$current_mt)
			{
				$current_element=$count;
			}
		$count++;
		}
		$element= count($ia_vector_mt);
		if ($current_element==0)
		{
			$previous_element= $element-1;
			$previous_mt= $ia_vector_mt[$previous_element]['url'];
			$next_mt=$ia_vector_mt[1]['url'];
			$previous_label= $ia_vector_mt[$previous_element]['label'];
			$next_label=$ia_vector_mt[1]['label'];
		}
		
		elseif ($current_element+1 == count($ia_vector_mt))
		{
			$previous_element= $current_element-1;
			$previous_mt= $ia_vector_mt[$previous_element]['url'];
			$next_mt=$ia_vector_mt[0]['url'];
			$previous_label=$ia_vector_mt[$previous_element]['label'];
			$next_label=$ia_vector_mt[0]['label'];
		}
		else
		{
			$previous_element= $current_element-1;
			$next_element= $current_element+1;
			$previous_mt= $ia_vector_mt[$previous_element]['url'];
			$next_mt=$ia_vector_mt[$next_element]['url'];
			$previous_label=$ia_vector_mt[$previous_element]['label'];
			$next_label=$ia_vector_mt[$next_element]['label'];
		}
		$_output .='<div id="'.$navigator_box.'">';
		$_output .='<a href="'.$previous_mt.'"><img src="'.$image_previous.'" alt="'.$previous_label.'"/></a>';			
		$_output .=$previous_label;
		$_output .=' | ';
		$_output .=$next_label;
		
		$_output .='<a href="'.$next_mt.'"><img src="'.$image_next.'" alt="'.$next_label.'"/></a>';			
		$_output .='</div>';
		}
		
		if ($ia_navigation_pattern=="all_to_all")
		{
		$_output .='<div id="'.$navigator_box.'">';
		foreach ($ia_vector_mt as $mt)
		{
			if ($mt['id']==$current_mt)
			{
				$_output .='<a class="'.$link_active_style.'" href="'.$mt['url'].'">'.$mt['label'].'</a>';
				continue;
			}
		$_output .='<a class="'.$link_style.'" href="'.$mt['url'].'">'.$mt['label'].'</a>';
		
		}
		$_output .='</div>';

		}
	}
	
    return $_output;
}

?>
