<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */


/**
 * Smarty {load_item} function plugin
 *
 * File:       function.load_item.php<br>
 * Type:       function<br>
 * Name:       load_item<br>
 * Date:       10.May.2007<br>
 * Purpose:    Prints out the item specified by the type (image, url, ...) or by the name (Home1_url Home1_video) <br>
 
 * Input:<br>
 *   - item_type				(required) - string that indicates the type of the item 	                                             you want to printed out
 *   - item_name				(optional) - string that indicates the name of the item 	                                             you want to printed out. If the name is not 	                                             specified, all the content of the item will                                             be printed out

 *   - error_box                (optional) - string that indicates the style applyed                                             to the error item
 *   - error_msg   				(optional) - string that indicates the error message that 				 											 the function printed out when a content for 			 											 the current language is not availeable. This 	  											 message is printed out only if the  									 											 administrator has specified this option.
 *   - error_style				(optional) - string that indicates the style applyed                                             to the error message 

 *   - text_box                 (optional) - string that indicates the style applyed                                             to the html item

 *   - img_box                  (optional) - string that indicates the style applyed                                             to the image item
 *   - img_description_style    (optional) - string that indicates the style class applyed                                             to the description of the images   

 *   - url_box   				(optional) - string that indicates the style applyed                                             to the url item 
 *   - url_text_style			(optional) - string that indicates the style class applyed                                             to the text of the url   

 *   - audio_information_style  (optional) - string that indicates the style class applyed                                             to the information displayed below the audio 				                                             player 											                                             (title, author, description)   
 *   - audio_box   				(optional) - string that indicates the style applyed                                             to the audio item 
 *   - audio_player_height		(optional) - String that indicates the heigh of the audio                                             player expressed in pixel. If the parameter                                             is not specified, the defaul heigh will be                                             20px   
 *   - audio_player_width		(optional) - String that indicates the width of the audio                                             player expressed in pixel. If the parameter                                             is not specified, the defaul width will be                                             320px
 
 *   - video_box   				(optional) - string that indicates the style applyed                                             to the video item 
 *   - video_information_style  (optional) - string that indicates the style class applyed                                             to the information displayed below the video 				                                             player (title, author, description) 
 *   - video_player_height		(optional) - String that indicates the heigh of the video                                             player expressed in pixel. If the parameter                                             is not specified, the defaul heigh will be                                             240px   
 *   - video_player_width		(optional) - String that indicates the width of the video                                             player expressed in pixel. If the parameter                                             is not specified, the defaul width will be                                             320px
	
 * @author     Gabriele Perego - Stefano Sormani
 * @version    1.0
 */

 
function smarty_function_load_item($params, &$smarty)
{
	$item_type = $params['item_type'];
	$item_name = $params['item_name'];
	$error_box = $params['error_box'];
	$error_msg = $params['error_msg'];
	$error_text_style = $params['error_text_style'];
	$text_box = $params['text_box'];
	$img_box = $params['img_box'];
	$img_description_style = $params['img_description_style'];
	$url_box = $params['url_box'];
	$url_text_style = $params['url_text_style'];
	$audio_box = $params['audio_box'];
	$audio_information_style = $params['audio_information_style'];
	$audio_player_height = $params['audio_player_height'];
	$audio_player_width = $params['audio_player_width'];
	$video_box = $params['video_box'];
	$video_information_style = $params['video_information_style'];
	$video_player_height = $params['video_player_height'];
	$video_player_width = $params['video_player_width'];
	$content = $smarty->get_template_vars('content');
	if (empty($params['item_type'])) 
	{
		$smarty->trigger_error("please insert 'item_type' parameter");
		exit;
	}
	$_output = '';

		switch($item_type) 
		{
			case "htmlText":
			$contentType=$content['htmlText'];
			if (count ($contentType))
			{
				if (empty($params['item_name'])) 
				{
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
							$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';	
						elseif (!strcmp($content['behaviour'],"default"))
						{
							$_output_temp ="";
							if(strcmp($content['content'],""))
								$_output_temp ='<div id ="'.$text_box.'">'.$content['content'].'</div>';
						}
						else
							$_output_temp = "";
						$_output .= $_output_temp;
					}
				}
				elseif (array_key_exists($item_name,$contentType))
				{
					$content=$contentType[$item_name];
					if (!strcmp($content['behaviour'],"error"))
							$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';	
					elseif (!strcmp($content['behaviour'],"default"))
					{
						$_output_temp ="";
						if(strcmp($content['content'],""))
							$_output_temp ='<div id ="'.$text_box.'">'.$content['content'].'</div>';
					}	
					else
						$_output_temp = "";
					$_output .= $_output_temp;
				}
				else
				{
					$smarty->trigger_error("the 'item_name' is not valid");
					exit;
				}
			}
			break; 
			
			case "image": 
			$contentType=$content['image'];
			if (count ($contentType))
			{
				if (empty($params['item_name'])) 
				{
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
							$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
						elseif (!strcmp($content['behaviour'],"default"))	
						{	
							$_output_temp ="";
							if(strcmp($content['img_thumb'],""))
							{
								$_output_temp ='<div id="'.$img_box.'"><a href="content/image/full/'.$content['img_full'].'" title="'.$content['description'].'" class="smoothbox"><img src="content/image/thumbnail/'.$content['img_thumb'].'" alt="'.$content['description'].'"/></a><br />';
								$_output_temp .='<span class ="'.$img_description_style.'">'.$content['description'].'</span>';
								$_output_temp .='</div>';
							}
						}
						else
							$_output_temp = "";
						$_output .= $_output_temp;
					}	
				}
				elseif (array_key_exists($item_name,$contentType))
				{
					$content=$contentType[$item_name];
					if (!strcmp($content['behaviour'],"error"))
						$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
					elseif (!strcmp($content['behaviour'],"default"))	
					{	
						$_output_temp ="";
						if(strcmp($content['img_thumb'],""))
						{
							$_output_temp ='<div id="'.$img_box.'"><a href="content/image/full/'.$content['img_full'].'" title="'.$content['description'].'" class="smoothbox"><img src="content/image/thumbnail/'.$content['img_thumb'].'" alt="'.$content['description'].'"/></a><br />';
							$_output_temp .='<span class ="'.$img_description_style.'">'.$content['description'].'</span>';
							$_output_temp .='</div>';
						}
					}
					else
						$_output_temp = "";
					$_output .= $_output_temp;
				}
				else
				{
					$smarty->trigger_error("the 'item_name' is not valid");
					exit;
				}
			}	
			break; 
			
			
			case "url": 
			$contentType=$content['url'];
			if (count ($contentType))
			{
				if (empty($params['item_name'])) 
				{
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
							$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
						
						elseif (!strcmp($content['behaviour'],"default"))	
						{
							$_output_temp ="";
							if(strcmp($content['url'],""))
								$_output_temp ='<div id="'.$url_box.'"><a class ="'.$url_text_style.'" href="'.$content['url'].'">'.$content['label'].'</a></div>';
						}
						else
							$_output_temp = "";
						$_output .= $_output_temp;
					}	
				}
				elseif (array_key_exists($item_name,$contentType))
				{
					$content=$contentType[$item_name];
					if (!strcmp($content['behaviour'],"error"))
							$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
						
					elseif (!strcmp($content['behaviour'],"default"))	
					{
						$_output_temp ="";
						if(strcmp($content['url'],""))
							$_output_temp ='<div id="'.$url_box.'"><a class ="'.$url_text_style.'" href="'.$content['url'].'">'.$content['label'].'</a></div>';
					}
					else
						$_output_temp = "";
					$_output .= $_output_temp;
				}
				else
				{
					$smarty->trigger_error("the 'item_name' is not valid");
					exit;
				}
			}
			break; 
			
			
			case "audio":
			$contentType=$content['audio'];
			if (count ($contentType))
			{
				if (empty($params['audio_player_height'])) 
				{
				$audio_player_height =20;
				}
				if (empty($params['audio_player_width'])) 
				{
				$audio_player_width =320;
				}
				if (empty($params['item_name'])) 
				{
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
						$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
						elseif (!strcmp($content['behaviour'],"default"))	
						{	
							$_output_temp ="";
							if(strcmp($content['file'],""))
							{
								$_output_temp ='<div id="'.$audio_box.'"><span class ="'.$audio_information_style.'">'.$content[title];
								$_output_temp .=' ('.$content[author].')</span>';
							
								$player="player_audio".$content['id'];
								$_output_temp .='<br/><span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to see this player.</span>';
						
								$_output_temp .='<script type="text/javascript">';
								$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "single", "'.$audio_player_width.'", "'.$audio_player_height.'", "7");';
								$_output_temp .='s3.addVariable("file","content/audio/'.$content['file'].'");';
								$_output_temp .='s3.addVariable("repeat","true");';
								$_output_temp .='s3.addVariable("showdigits","true");';
								$_output_temp .='s3.write("'.$player.'");';
								$_output_temp .='</script>';
								$_output_temp .='<br/>';
								$_output_temp .='<span class ="'.$audio_information_style.'">'.$content[description];
								$_output_temp .='</span></div>';
							}	
						}
						else
							$_output_temp = "";
						$_output .= $_output_temp;
					}	
				}
				elseif (array_key_exists($item_name,$contentType))
				{
					$content=$contentType[$item_name];
					if (!strcmp($content['behaviour'],"error"))
						$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
					elseif (!strcmp($content['behaviour'],"default"))	
					{	
						$_output_temp ="";
						if(strcmp($content['file'],""))
						{
							$_output_temp ='<div id="'.$audio_box.'"><span class ="'.$audio_information_style.'">'.$content[title];
							$_output_temp .=' ('.$content[author].')</span>';
						
							$player="player_audio".$content['id'];
							$_output_temp .='<br/><span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to see this player.</span>';
					
							$_output_temp .='<script type="text/javascript">';
							$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "single", "'.$audio_player_width.'", "'.$audio_player_height.'", "7");';
							$_output_temp .='s3.addVariable("file","content/audio/'.$content['file'].'");';
							$_output_temp .='s3.addVariable("repeat","true");';
							$_output_temp .='s3.addVariable("showdigits","true");';
							$_output_temp .='s3.write("'.$player.'");';
							$_output_temp .='</script>';
							$_output_temp .='<br/>';
							$_output_temp .='<span class ="'.$audio_information_style.'">'.$content[description];
							$_output_temp .='</span></div>';
						}	
					}
					else
						$_output_temp = "";
					$_output .= $_output_temp;
				}
				else
				{
					$smarty->trigger_error("the 'item_name' is not valid");
					exit;
				}
			}
			break; 
			
			case "video": 
			$contentType=$content['video'];
			if (count ($contentType))
			{
				if (empty($params['video_player_height'])) 
				{
				$video_player_height =240;
				}
				if (empty($params['video_player_width'])) 
				{
				$video_player_width =320;
				}
				if (empty($params['item_name'])) 
				{
					foreach ($contentType as $content)
					{
						if (!strcmp($content['behaviour'],"error"))
						$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
						elseif (!strcmp($content['behaviour'],"default"))	
						{	
							$_output_temp ="";
							if(strcmp($content['file'],""))
							{
								$_output_temp ='<div id="'.$video_box.'"><span class ="'.$video_information_style.'">'.$content[title];
								$_output_temp .=' ('.$content[author].')</span><br/>';
								$player="player_video".$content['id'];
								$_output_temp .='<span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to see this player.</span>';
								$_output_temp .='<script type="text/javascript">';
								$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "playlist", "'.$video_player_width.'", "'.$video_player_height.'", "7");';
								$_output_temp .='s3.addVariable("file","../content/video/'.$content['file'].'");';
								$_output_temp .='s3.addVariable("repeat","true");';
								$_output_temp .='s3.addVariable("showdigits","true");';
								$_output_temp .='s3.write("'.$player.'");';
								$_output_temp .='</script>';
								$_output_temp .='<br/>';
								$_output_temp .='<span class ="'.$video_information_style.'">'.$content[description];
								$_output_temp .='</span></div>';
							}
						}
						else
							$_output_temp = "";
						$_output .= $_output_temp;
					}	
				}
				elseif (array_key_exists($item_name,$contentType))
				{
					$content=$contentType[$item_name];
					if (!strcmp($content['behaviour'],"error"))
						$_output_temp ='<div id ="'.$error_box.'"><span class ="'.$error_style.'">'.$error_msg.'</span></div>';
					elseif (!strcmp($content['behaviour'],"default"))	
					{	
						$_output_temp ="";
						if(strcmp($content['file'],""))
						{
							$_output_temp ='<div id="'.$video_box.'"><span class ="'.$video_information_style.'">'.$content[title];
							$_output_temp .=' ('.$content[author].')</span><br/>';
							$player="player_video".$content['id'];
							$_output_temp .='<span id="'.$player.'"><a href="http://www.macromedia.com/go/getflashplayer">Get the Flash Player</a> to see this player.</span>';
							$_output_temp .='<script type="text/javascript">';
							$_output_temp .='var s3 = new SWFObject("player/mediaplayer.swf", "playlist", "'.$video_player_width.'", "'.$video_player_height.'", "7");';
							$_output_temp .='s3.addVariable("file","../content/video/'.$content['file'].'");';
							$_output_temp .='s3.addVariable("repeat","true");';
							$_output_temp .='s3.addVariable("showdigits","true");';
							$_output_temp .='s3.write("'.$player.'");';
							$_output_temp .='</script>';
							$_output_temp .='<br/>';
							$_output_temp .='<span class ="'.$video_information_style.'">'.$content[description];
							$_output_temp .='</span></div>';
						}
					}
					else
						$_output_temp = "";
					$_output .= $_output_temp;
				}	
				else
				{
					$smarty->trigger_error("the 'item_name' is not valid");
					exit;
				}
			}
			break; 
			
			default:
				break;
				
		}

    return $_output;
}
?>

